@@ -165,7 +165,7 @@ int main(int argc, char **argv)
 {
     int i, use_stdin, use_mbox;
     char *configfile = NULL;
-    char **tlang;
+    char **tlang, *locale_code;
     int cmd_show_variables;
     int print_usage;
 
@@ -350,12 +350,27 @@ int main(int argc, char **argv)
      * valid language. Otherwise strange things happen quickly.
      */
 
-    if ((tlang = valid_language(set_language)) == NULL) {
+    if (strlen(set_language) > 2) {
+	locale_code = strsav(set_language);
+	set_language[2] = 0;	/* shorten to 2-letter code */
+    }
+    else
+	locale_code = NULL;
+
+    if ((tlang = valid_language(set_language, &locale_code)) == NULL) {
 	sprintf(errmsg, "\"%s\" %s.", set_language,
 		lang[MSG_LANGUAGE_NOT_SUPPORTED]);
 	cmderr(errmsg);
     }
 
+#ifdef HAVE_LOCALE_H
+    if ( ! setlocale(LC_ALL, locale_code) ) {
+        sprintf(errmsg, "WARNING: locale \"%s\", not supported.\n",
+		locale_code);
+        fprintf(stderr, errmsg);
+    }
+#endif
+	
     lang = tlang;		/* A good language, make it so. */
 
     if (print_usage)		/* Print the usage message and terminate */
@@ -484,11 +499,6 @@ int main(int argc, char **argv)
      * A bigger win on larger archives.
      */
 
-    if (set_htmlbody && !strcasecmp(set_htmlbody, "NONE")) {
-	free(set_htmlbody);
-	set_htmlbody = NULL;
-    }
-
     if (set_hmail && !strcasecmp(set_hmail, "NONE")) {
 	free(set_hmail);
 	set_hmail = NULL;
@@ -567,15 +577,22 @@ int main(int argc, char **argv)
 
 	if (set_show_msg_links) {
 	    fixnextheader(set_dir, amount_old, -1);
-	    if (set_showreplies)
-		fixreplyheader(set_dir, amount_old, 0);
-	    fixthreadheader(set_dir, amount_old);
+	    for (i = amount_old; i < amount_new; ++i) {
+		if (set_showreplies)
+		    fixreplyheader(set_dir, i, 0, amount_old);
+		fixthreadheader(set_dir, i, amount_old);
+	    }
 	}
     }
     else {
 	amount_new =
 	    parsemail(set_mbox, use_stdin, set_readone, set_increment,
 		      set_dir, set_inlinehtml, 0);	/* number from 0 */
+	if (!matches_existing(0)) {
+	    fprintf(stderr, "Warning: first message in mailbox does not "
+		    "match first message in archive\n"
+		    "or obsolete gdbm file present.\n");
+	}
 	if (set_linkquotes)
 	    analyze_headers(max_msgnum + 1);
 	writearticles(0, max_msgnum + 1);
