@@ -29,6 +29,7 @@
 struct language_entry {
     char     *langcode;
     char     **mtable;
+    char     *locale_code;
 };
 
 /* print.c */
@@ -171,6 +172,7 @@ struct language_entry {
 #define MSG_DEL_SHORT                            115
 #define MSG_TXT_VERSION                          116
 #define MSG_FILTERED_OUT                         117
+#define MSG_FROM                                 118
 
 #ifdef MAIN_FILE
 
@@ -305,9 +307,139 @@ char *de[] = {       /* German */
   "(deleted message)", /* MSG_DEL_SHORT                            -HTML */
   "Original text of this message", /* MSG_TXT_VERSION                          -HTML */
   "This message has been filtered out",        /* MSG_FILTERED_OUT -HTML */
+  "Autor",                                /* MSG_FROM              -HTML*/
   NULL,                                   /* End Of Message Table - NOWHERE*/
 };
 
+/*
+** Polish version of the language table (Polska wersja tabeli jzykowej)
+** Translation by Adam T. Tkocz <adam@storm.pl>
+*/
+
+char *pl[] = {                      /* English */
+  "Nowa wiadomo",                 /* New Message        -HTML*/
+  "Odpowiedz",                      /* Reply              -HTML*/
+  "O tej licie",                   /* About this list    -HTML*/
+  "D strony",                     /* End of Messages    -HTML*/
+  "Gra strony",                    /* Start of Messages  -HTML*/
+  "Wg daty",                        /* Date view          -HTML*/
+  "Wg wtkw",                      /* Thread view        -HTML*/
+  "Wg tematw",                     /* Subject view       -HTML*/
+  "Wg autorw",                     /* Author view        -HTML*/
+  "Inne grupy",                     /* Other groups       -HTML*/
+  "Wiadomoci",                     /* Messages           -HTML*/
+  "Pocztek",                       /* Starting           -HTML*/
+  "Koniec",                         /* Ending             -HTML*/
+  "O tym archiwum",                 /* About this archive -HTML*/
+  "sortowane wg",                   /* Messages sorted by -HTML*/
+  "Inne archiwa maili",             /* Other mail archives -HTML*/
+  "Wg daty",                        /* By Date             -HTML*/
+  "Najwiesze wiadomoci",         /* Most recent messages-HTML*/
+  "autora",                         /* author              -HTML*/
+  "datay",                          /* date                -HTML*/
+  "wtku",                          /* thread              -HTML*/
+  "tematu",                         /* subject             -HTML*/
+  "Dla opcji",                      /* for options       -STDOUT*/
+  "Zapisywanie wiadomoci do",      /* Writing messages to-STDOUT*/
+  "Zapisywanie indeksu dat do",     /* Writing date index to-STDOUT*/
+  "Zapisywanie indeksu wtkw do",  /* Writing thread index to -STDOUT*/
+  "Zapisywanie indeksu tematw do", /* Writing subject index to-STDOUT*/
+  "Zapisywanie indeksu autorw do", /* Writing author index to-STDOUT*/
+  "Data ostatniej wiadomoci",      /* Last message date   -HTML*/
+  "Zarchiwizowane w",               /* Archived on         -HTML*/
+  "Niedozwolone chmod",             /* Can not chmod     -STDERR*/
+  "Nie mona zapisa",              /* Could not write   -STDERR*/
+  "Nastpna wiadomo",             /* Next message        -HTML*/
+  "Poprzednia wiadomo",           /* Previous message    -HTML*/
+  "Przypuszczalnie w odpowiedzi na",/* Maybe in reply to   -HTML*/
+  "W odpowiedzi na",                /* In reply to         -HTML*/
+  "Nastpna w wtku",               /* Next in thread      -HTML*/
+  "Prawdopodobna odpowied",        /* Maybe reply         -HTML*/
+  "Wg wtku",                       /* By Thread           -HTML*/
+  "Wg tematu",                      /* By Subject          -HTML*/
+  "Wg autora",                      /* By Author           -HTML*/
+  "Nie mona stworzy katalogu",    /* Can not create directory -STDERR*/
+  "Tworzenie katalogu",             /* Creating directory -STDOUT*/
+  "Parametry konfiguracji",         /* Configuration Values -STDOUT*/
+  "cieka",                        /* path              -STDOUT*/
+  "Przekroczona pami!",           /* Ran out of memory!-STDERR*/
+  "To archiwum zostao wygenerowane przez",  /* This archive was generated by -HTML*/
+  "Elementy",                       /* Elements          -STDOUT*/
+  "adnych elementw",              /* No Elements       -STDOUT*/
+  "Nie mona otworzy archiwum",    /* Cannot open mail archive */
+  "Czytanie nowego nagwka",       /* Reading new header... -STDOUT   */
+  "adowanie mailboxa",             /* Loading mailbox      -STDOUT  */
+  "kodowanie nie jest obsugiwane", /* encoding is not supported, stored as-is -HTML*/
+  "wiadomoci",                     /* messages             -HTML*/
+  "Wersja",                         /* Version            -STDOUT*/
+  "Wersja aty",                    /* Patchlevel         -STDOUT*/
+  "Dokumentacja",                   /* Docs               -STDOUT*/
+  "Polecenia i zmienne",            /* Command and Control Variables-STDOUT*/
+  "Tak",                            /* Yes                -STDOUT*/
+  "Nie",                            /* No                 -STDOUT*/
+  "O tym archiwum: nie uywane",    /* About the archive: not used-STDOUT */
+  "Inne archiwa: nie uywane",      /* Other archives: not used-STDOUT*/
+  "adres nie zosta uyty",         /* address not used -STDOUT*/
+  "Wbudowane <BODY> zostao uyte", /* Builtin <BODY> statement used-STDOUT*/
+  "Nie mona odczyta pliku ani stdin.", /* Cannot read from both file and stdin. -STDERR*/
+  "Opcje",                          /* Options                -STDOUT*/
+  "URL do innych arciww",          /* URL to other archives  -STDOUT*/
+  "URL do informacji o archiwum",   /* URL to archive information -STDOUT*/
+  "Plik konfiguracyjny do wczytania", /* Configuration file to read in -STDOUT*/
+  "Katalog do zapisu plikw HTML",  /* The directory to save HTML files in -STDOUT*/
+  "Czytaj wiadomoci z stdin",      /* Read messages from standard input -STDOUT*/
+  "Podaj nazw archiwum",           /* What to name the output archive -STDOUT*/
+  "Archiwum do wczytania",          /* Mail archive to read in -STDOUT*/
+  "Poka postpy",                  /* Show progress           -STDOUT*/
+  "Poka tylko zmienne konfiguracyjne", /* Show configuration variables only -STDOUT*/
+  "Poka wersj i wyjd",           /* Show version information and exit -STDOUT*/
+  "Uzupelnij archiwum o jedn wiadomo", /* Update archive by one article -STDOUT*/
+  "Zastp poprzednia wiadomo",    /* Overwrite previous messages -STDOUT*/
+  "Wybierz uywany jzyk",          /* Specify language to use     -STDOUT*/
+  "Uycie",                         /* Usage                       -STDOUT*/
+  "Jzyk nie jest wspierany",       /* Language not supported  -STDERR*/
+  "Nie ustawione",                  /* Not set     -STDOUT*/
+  "Nie uywane",                    /* Not used  -STDOUT*/
+  "Stworzono zacznik",            /* Created attachment file     -STDOUT*/
+  "zacznik",                      /* attachment                    -HTML*/
+  "tryb",                           /* mode                        -STDOUT*/
+  "Czytanie starych nagwkw",     /* Reading old headers      -STDOUT*/
+  "",                               /* tylko do wyrwnania       -STDOUT*/
+  "BD",                           /* ERROR                       -STDERR*/
+  "Adres wypisujcy z listy",       /* The submission address of the list-STDERR*/
+  "Czytaj tylko jedn wiadomo",
+  "Autor",                          /* author              -HTML*/
+  "Data",                           /* date                -HTML*/
+  "Temat",                          /* subject             -HTML*/
+  "Wybierz",                        /* Mail actions (MA) header -HTML*/
+  "wylij nowy temat",              /* MA New Message      -HTML*/
+  "odpowiedz na t wiadomo",      /* MA Reply            -HTML*/
+  "Zestawienie miesicy",           /* monthly             -HTML*/
+  "Zestawienie lat",                /* yearly              -HTML*/
+  "Utwrz cache nagowkw GDBM",    /* Build a GDBM header cache -STDOUT*/
+  "Tworzenie indeksu GDBM... ",     /* Creating gdbm index -STDOUT*/
+  "Nie mona utworzy pliku GDBM... ",  /* Can't create gdbm index     -STDOUT*/
+  "Zachowaj archiwum mbox",         /* Maintain an mbox archive    -STDOUT*/
+  "Nie mona odczyta ani zapisa mailboxa.", /* "Can't both read from and write to an mbox." -STDOUT*/
+  "Wg zacznikw",                  /* Attachment view -HTML*/
+  "Wg wiadomoci z zacznikami",    /* By messages with attachments -HTML*/
+  "Zapisywanie indeksu zacznikw", /* Writing attachment index to -STDOUT*/
+  "bajtw",                          /* file size, so far only for attachments  -HTML */
+  "Nie mona stworzy aliasa",       /* MSG_CANNOT_CREATE_SYMLINK -STDOUT */
+  "Nie mona usun pliku",          /* MSG_CANNOT_UNLINK      -STDOUT */
+  "Poprzedni katalog",               /* MSG_PREV_DIRECTORY  -HTML */
+  "Nastpny katalog",                /* MSG_NEXT_DIRECTORY    -HTML */
+  "Lista Katalogw",                 /* MSG_FOLDERS_INDEX   -HTML */
+  "Ta wiadomo zostaa usunita z archiwum", /* MSG_DELETED  -HTML */
+  "Ta wiadomo jest przedawniona",  /*MSG_EXPIRED -HTML */
+  "(usunita wiadomo)",            /* MSG_DEL_SHORT     -HTML */
+  "Tekst tej zawartoci",            /* MSG_TXT_VERSION     -HTML */
+  "Ta wiadomo zostaa odfiltrowana",        /* MSG_FILTERED_OUT -HTML */
+  "Autor",                          /* MSG_FROM              -HTML*/
+  NULL,                              /* End Of Message Table      - NOWHERE*/
+};
+
+
 /*
 ** English version of the language table
 */
@@ -432,6 +564,7 @@ char *en[] = {       /* English */
   "(deleted message)", /* MSG_DEL_SHORT                            -HTML */
   "Original text of this message", /* MSG_TXT_VERSION                          -HTML */
   "This message has been filtered out",        /* MSG_FILTERED_OUT -HTML */
+  "From",                        /* MSG_FROM                      -HTML*/
   NULL,                          /* End Of Message Table      - NOWHERE*/
 };
 
@@ -568,6 +701,7 @@ char *es[] = {       /* Espanol/Spanish */
   "(deleted message)", /* MSG_DEL_SHORT                            -HTML */
   "Original text of this message", /* MSG_TXT_VERSION                          -HTML */
   "This message has been filtered out",        /* MSG_FILTERED_OUT -HTML */
+  "Autor",                            /* MSG_FROM - HTML*/
   NULL,                               /* End Of Message Table */
 };
 
@@ -694,6 +828,7 @@ char *fi[] = {       /* Finnish */
   "(deleted message)", /* MSG_DEL_SHORT                            -HTML */
   "Original text of this message", /* MSG_TXT_VERSION                          -HTML */
   "This message has been filtered out",        /* MSG_FILTERED_OUT -HTML */
+  "Kirjoittajan mukaan",                 /* MSG_FROM                  -HTML*/
   NULL,                              /* End Of Message Table      - NOWHERE*/
 };
 
@@ -703,126 +838,127 @@ char *fi[] = {       /* Finnish */
 */
 
 char *fr[] = {       /* French */
-  "Nouveau Message",                     /* New Message        -HTML*/
-  "R&eacute;ponse",                      /* Reply              -HTML*/
-  "A propos de cette liste",             /* About this list    -HTML*/
-  "Fin des Messages",                    /* End of Messages    -HTML*/
-  "D&eacute;but des Messages",           /* Start of Messages  -HTML*/
-  "Liste par Date",                      /* Date view          -HTML*/
-  "Liste par Th&egrave;me",              /* Thread view        -HTML*/
-  "Liste par Sujet",                     /* Subject view       -HTML*/
-  "Liste par Auteur",                    /* Author view        -HTML*/
-  "Autres groupes",                      /* Other groups       -HTML*/
-  "Messages",                            /* Messages           -HTML*/
-  "D&eacute;but",                        /* Starting           -HTML*/
-  "Fin",                                 /* Ending             -HTML*/
-  "A propos de cette archive",           /* About this archive -HTML*/
-  "Messages class&eacute;s par",         /* Messages sorted by -HTML*/
-  "Autres archives",                     /* Other mail archives -HTML*/
-  "Par Date",                            /* By Date             -HTML*/
-  "Messages les plus r&eacute;cents",    /* Most recent messages-HTML*/
-  "auteur",                              /* author              -HTML*/
-  "date",                                /* date                -HTML*/
-  "th&egrave;eme",                       /* thread              -HTML*/
-  "sujet",                               /* subject             -HTML*/
-  "pour les options",                    /* for options       -STDOUT*/
-  "Ecriture des messages vers",          /* Writing messages to-STDOUT*/
-  "Ecriture de l'index 'date' vers",     /* Writing date index to-STDOUT*/
-  "Ecriture de l'index 'thme' vers", /* Writing thread index to -STDOUT*/
-  "Ecriture de l'index 'sujet' vers",    /* Writing subject index to-STDOUT*/
-  "Ecriture de l'index 'auteur' vers",   /* Writing author index to-STDOUT*/
-  "Date du dernier message",             /* Last message date   -HTML*/
-  "Archiv&eacute; le",                   /* Archived on         -HTML*/
-  "Ne peut effectuer de chmod",          /* Can not chmod     -STDERR*/
-  "Ne peut crire",                   /* Could not write   -STDERR*/
-  "Message suivant",                     /* Next message        -HTML*/
-  "Message pr&eacute;c&eacute;dent",     /* Previous message    -HTML*/
-  "Sans doute en r&eacute;ponse ",   /* Maybe in reply to   -HTML*/
-  "En r&eacute;ponse ",              /* In reply to         -HTML*/
-  "Suivant dans le th&egrave;me",        /* Next in thread      -HTML*/
-  "Sans doute en r&eacute;ponse",        /* Maybe reply         -HTML*/
-  "Par Th&egrave;me",                    /* By Thread           -HTML*/
-  "Par Sujet",                           /* By Subject          -HTML*/
-  "Par Auteur",                          /* By Author           -HTML*/
-  "Ne peut crer le rpertoire",   /* Can not create directory -STDERR*/
-  "Cration du rpertoire",        /* Creating directory -STDOUT*/
-  "Valeurs configures",              /* Configuration Values -STDOUT*/
-  "chemin",                              /* path              -STDOUT*/
-  "Plus assez de mmoire!",           /* Ran out of memory!-STDERR*/
+  "Nouveau Message",                       /* New Message        -HTML*/
+  "R&eacute;ponse",                        /* Reply              -HTML*/
+  "A propos de cette liste",               /* About this list    -HTML*/
+  "Fin des Messages",                      /* End of Messages    -HTML*/
+  "D&eacute;but des Messages",             /* Start of Messages  -HTML*/
+  "Liste par Date",                        /* Date view          -HTML*/
+  "Liste par Th&egrave;me",                /* Thread view        -HTML*/
+  "Liste par Sujet",                       /* Subject view       -HTML*/
+  "Liste par Auteur",                      /* Author view        -HTML*/
+  "Autres groupes",                        /* Other groups       -HTML*/
+  "Messages",                              /* Messages           -HTML*/
+  "D&eacute;but",                          /* Starting           -HTML*/
+  "Fin",                                   /* Ending             -HTML*/
+  "A propos de cette archive",             /* About this archive -HTML*/
+  ", class&eacute;s par",                  /* Messages sorted by -HTML*/
+  "Autres archives",                       /* Other mail archives -HTML*/
+  "par Date",                              /* By Date             -HTML*/
+  "Messages les plus r&eacute;cents",      /* Most recent messages-HTML*/
+  "auteur",                                /* author              -HTML*/
+  "date",                                  /* date                -HTML*/
+  "th&egrave;me",                          /* thread              -HTML*/
+  "sujet",                                 /* subject             -HTML*/
+  "pour les options",                      /* for options       -STDOUT*/
+  "Ecriture des messages vers",            /* Writing messages to-STDOUT*/
+  "Ecriture de l'index 'date' dans",       /* Writing date index to-STDOUT*/
+  "Ecriture de l'index 'thme' dans",      /* Writing thread index to -STDOUT*/
+  "Ecriture de l'index 'sujet' dans",      /* Writing subject index to-STDOUT*/
+  "Ecriture de l'index 'auteur' dans",     /* Writing author index to-STDOUT*/
+  "Date du dernier message",               /* Last message date   -HTML*/
+  "Archiv&eacute; le",                     /* Archived on         -HTML*/
+  "Ne peut effectuer de chmod",            /* Can not chmod     -STDERR*/
+  "Ne peut crire",                        /* Could not write   -STDERR*/
+  "Message suivant",                       /* Next message        -HTML*/
+  "Message pr&eacute;c&eacute;dent",       /* Previous message    -HTML*/
+  "Sans doute en r&eacute;ponse &agrave;", /* Maybe in reply to   -HTML*/
+  "En r&eacute;ponse &agrave;",             /* In reply to         -HTML*/
+  "Suivant dans le th&egrave;me",          /* Next in thread      -HTML*/
+  "Sans doute en r&eacute;ponse",          /* Maybe reply         -HTML*/
+  "par Thme",                      /* By Thread           -HTML*/
+  "par Sujet",                             /* By Subject          -HTML*/
+  "par Auteur",                            /* By Author           -HTML*/
+  "Ne peut crer le rpertoire",           /* Can not create directory -STDERR*/
+  "Cration du rpertoire",                /* Creating directory -STDOUT*/
+  "Valeurs configures",                   /* Configuration Values -STDOUT*/
+  "chemin",                                /* path              -STDOUT*/
+  "Plus assez de mmoire!",                 /* Ran out of memory!-STDERR*/
   "Cette archive a &eacute;t&eacute; cr&eacute;&eacute;e par",  /* This archive was generated by-HTML*/
-  "Elments",                         /* Elements          -STDOUT*/
-  "Aucun Elment",                    /* No Elements       -STDOUT*/
-  "Ne peut ouvrir l'archive de mail",    /* Cannot open mail archive */
-  "Lecture du nouvel en-tte...",     /* Reading new header...-STDOUT   */
-  "Chargement de la mailbox",            /* Loading mailbox      -STDOUT   */
-  "encodage non support, stock tel quel", /* encoding is not supported, stored as-is -HTML*/
-  "messages",                            /* messages             -HTML*/
-  "Version",                             /* Version            -STDOUT*/
-  "Patchlevel",                          /* Patchlevel         -STDOUT*/
-  "Documents",                           /* Docs               -STDOUT*/
-  "Variables de Commande et de Contrle", /* Command and Control Variables-STDOUT*/
-  "Oui",                                 /* Yes                -STDOUT*/
-  "Non",                                 /* No                 -STDOUT*/
-  "A propos de l'archive: non utilis", /* About the archive: not used-STDOUT */
-  "Autres archives: non utilis",     /* Other archives: not used-STDOUT*/
-  "adresse non utilise",             /* address not used        -STDOUT*/
-  "Utilisation de la dclaration <BODY>", /* Builtin <BODY> statement used-STDOUT*/
-  "Ne peut lire  la fois un fichier et le stdin", /* Cannot read from both file and stdin. -STDERR*/
-  "Options",                             /* Options                -STDOUT*/
-  "URL vers les autres archives",        /* URL to other archives  -STDOUT*/
+  "Elments",                              /* Elements          -STDOUT*/
+  "Aucun Elment",                         /* No Elements       -STDOUT*/
+  "Ne peut ouvrir l'archive de mail",      /* Cannot open mail archive */
+  "Lecture du nouvel en-tte...",          /* Reading new header...-STDOUT   */
+  "Chargement de la boite aux lettres",    /* Loading mailbox      -STDOUT   */
+  "encodage non support, stock tel quel",/* encoding is not supported, stored as-is -HTML*/
+  "messages",                              /* messages             -HTML*/
+  "Version",                               /* Version            -STDOUT*/
+  "Revision",                              /* Patchlevel         -STDOUT*/
+  "Documents",                             /* Docs               -STDOUT*/
+  "Variables de Commande et de Contrle",  /* Command and Control Variables-STDOUT*/
+  "Oui",                                   /* Yes                -STDOUT*/
+  "Non",                                   /* No                 -STDOUT*/
+  "A propos de l'archive: non utilis",    /* About the archive: not used-STDOUT */
+  "Autres archives: non utilis",          /* Other archives: not used-STDOUT*/
+  "adresse non utilise",                  /* address not used        -STDOUT*/
+  "Utilisation de la dclaration <BODY>",  /* Builtin <BODY> statement used-STDOUT*/
+  "Impossible de lire simulatanment un fichier et le flot d'entre standard (stdin)", /* Cannot read from both file and stdin. -STDERR*/
+  "Options",                               /* Options                -STDOUT*/
+  "URL vers les autres archives",          /* URL to other archives  -STDOUT*/
   "URL vers les informations sur l'archive",  /* URL to archive information -STDOUT*/
-  "Fichier de configuration  lire",  /* Configuration file to read in -STDOUT*/
-  "Rpertoire o sauver les fichiers HTML", /* The directory to save HTML files in -STDOUT*/
-  "Lecture des messages depuis le stdin", /* Read messages from standard input -STDOUT*/
-  "Nom de l'archive de sortie",          /* What to name the output archive -STDOUT*/
-  "Archive de mail lue",                 /* Mail archive to read in -STDOUT*/
-  "Voir la progression",                 /* Show progress           -STDOUT*/
+  "Fichier de configuration  lire",       /* Configuration file to read in -STDOUT*/
+  "Rpertoire o sauver les fichiers HTML",/* The directory to save HTML files in -STDOUT*/
+  "Lecture des messages depuis le flot d'entre standard (stdin)", /* Read messages from standard input -STDOUT*/
+  "Nom de l'archive de sortie",            /* What to name the output archive -STDOUT*/
+  "Archive d'email  lire",                   /* Mail archive to read in -STDOUT*/
+  "Voir la progression",                   /* Show progress           -STDOUT*/
   "Voir les variables de configuration seulement", /* Show configuration variables only -STDOUT*/
-  "Afficher la version et quitter",      /* Show version information and exit -STDOUT*/
-  "Mettre  jour l'archive d'un article", /* Update archive by one article -STDOUT*/
-  "Ecraser les messages prcdents", /* Overwrite previous messages -STDOUT*/
-  "Spcifier la langue  utiliser", /* Specify language to use     -STDOUT*/
-  "Usage",                               /* Usage           -STDOUT*/
-  "Langue non supporte",             /* Language not supported -STDERR*/
-  "Non dfini",                       /* Not set        -STDOUT*/
-  "Non utilis",                      /* Not used       -STDOUT*/
-  "Fichier d'attachement cr",    /* Created attachment file -STDOUT*/
-  "attachement",                         /* attachment     -HTML*/
-  "mode",                                /* mode           -STDOUT*/
-  "Lecture des anciens en-ttes",     /* Reading old headers -STDOUT*/
-  "",                                    /* for alignment only       -STDOUT*/
-  "ERREUR",                              /* ERROR                    -STDERR*/
-  "Adresse de soumission de la liste", 
-                           /* The submission address of the list-STDERR*/
+  "Afficher la version et quitter",        /* Show version information and exit -STDOUT*/
+  "Mettre  jour l'archive d'un article",  /* Update archive by one article -STDOUT*/
+  "Ecraser les messages prcdents",       /* Overwrite previous messages -STDOUT*/
+  "Spcifier la langue  utiliser",        /* Specify language to use     -STDOUT*/
+  "Utilisation",                           /* Usage           -STDOUT*/
+  "Langue non supporte",                  /* Language not supported -STDERR*/
+  "Non dfini",                            /* Not set        -STDOUT*/
+  "Non utilis",                           /* Not used       -STDOUT*/
+  "Fichier attach cr",                  /* Created attachment file -STDOUT*/
+  "fichier attach&eacute;",                /* attachment     -HTML*/
+  "mode",                                  /* mode           -STDOUT*/
+  "Lecture des anciens en-ttes",          /* Reading old headers -STDOUT*/
+  "",                                      /* for alignment only       -STDOUT*/
+  "ERREUR",                                /* ERROR                    -STDERR*/
+  "Adresse d'envoi  la liste", 
+                                           /* The submission address of the list-STDERR*/
   "Lire seulement un mail depuis l'entre",
-  "Auteur",                              /* author              -HTML*/
-  "Date",                                /* date                -HTML*/
-  "Sujet",                               /* subject             -HTML*/
-  "Actions sur les mails",               /* Mail actions (MA) header -HTML*/
-  "cr&eacute;er un nouveau th&egrave;me",     /* MA New Message      -HTML*/
-  "r&eacute;pondre &agrave; ce message",      /* MA Reply            -HTML*/
-  "Summary of Monthly Index Files",      /* monthly             -HTML*/
-  "Summary of Yearly Index Files",       /* yearly              -HTML*/
-  "Build a GDBM header cache",   /* Build a GDBM header cache   -STDOUT*/
-  "Creating gdbm index... ",     /* Creating gdbm index         -STDOUT*/
-  "Can't create gdbm file... ",  /* Can't create gdbm index     -STDOUT*/
-  "Maintain an mbox archive",    /* Maintain an mbox archive    -STDOUT*/
-  "Can't both read from and write to an mbox.", /* "Can't both read from and write to an mbox." -STDOUT*/
-  "Liste par attachements",               /* Attachment view  -HTML*/
-  "Par messages avec attachments",	  /* By messages with attachments -HTML*/
-  "Ecriture de l'index 'attachement' vers",	  /* Writing attachment index to -STDOUT*/
-  "bytes",		    /* file size, so far only for attachments  -HTML */
-  "Cannot create symbolic link", /* MSG_CANNOT_CREATE_SYMLINK     -STDOUT */
-  "Cannot remove file", /* MSG_CANNOT_UNLINK                       -STDOUT */
-  "Previous Folder",  /* MSG_PREV_DIRECTORY                     -HTML */
-  "Next Folder",      /* MSG_NEXT_DIRECTORY                     -HTML */
-  "List of Folders",  /* MSG_FOLDERS_INDEX                      -HTML */
-  "This message has been deleted from the archive", /* MSG_DELETED -HTML */
-  "This message has expired",                       /* MSG_EXPIRED -HTML */
-  "(deleted message)", /* MSG_DEL_SHORT                            -HTML */
-  "Original text of this message", /* MSG_TXT_VERSION                          -HTML */
-  "This message has been filtered out",        /* MSG_FILTERED_OUT -HTML */
-  NULL,                                  /* End Of Message Table  - NOWHERE*/
+  "Auteur",                                /* author              -HTML*/
+  "Date",                                  /* date                -HTML*/
+  "Sujet",                                 /* subject             -HTML*/
+  "Actions sur les mails",                 /* Mail actions (MA) header -HTML*/
+  "cr&eacute;er un nouveau th&egrave;me",  /* MA New Message      -HTML*/
+  "r&eacute;pondre &agrave; ce message",   /* MA Reply            -HTML*/
+  "Summary of Monthly Index Files",        /* monthly             -HTML*/
+  "Summary of Yearly Index Files",         /* yearly              -HTML*/
+  "Creation d'un cache GDBM pour les en-ttes",  /* Build a GDBM header cache   -STDOUT*/
+  "Generation de l'index GDBM... ",               /* Creating gdbm index         -STDOUT*/
+  "Impossible de crer un fichier GDBM... ",    /* Can't create gdbm index     -STDOUT*/
+  "Maintenance d'une archive email (mbox)",     /* Maintain an mbox archive    -STDOUT*/
+  "Impossible de lire et d'crire simultanment dans une archive email (mbox)", /* "Can't both read from and write to an mbox." -STDOUT*/
+  "Liste par fichier attachs",            /* Attachment view  -HTML*/
+  "par messages avec fichiers attachs",    /* By messages with attachments -HTML*/
+  "Ecriture de l'index 'fichiers attachs' dans",/* Writing attachment index to -STDOUT*/
+  "octets",		                   /* file size, so far only for attachments  -HTML */
+  "Impossible de crer un lien symbolique",/* MSG_CANNOT_CREATE_SYMLINK     -STDOUT */
+  "Impossible de supprimer le fichier",    /* MSG_CANNOT_UNLINK                       -STDOUT */
+  "Dossier prcdent",                     /* MSG_PREV_DIRECTORY                     -HTML */
+  "Dossier suivant",                       /* MSG_NEXT_DIRECTORY                     -HTML */
+  "Liste des dossiers",                    /* MSG_FOLDERS_INDEX                      -HTML */
+  "Ce message a &eacute;t&eacute; supprim&eacute; de l'archive", /* MSG_DELETED -HTML */
+  "Ce message est trop vieux",             /* MSG_EXPIRED -HTML */
+  "(message supprim&eacute)",              /* MSG_DEL_SHORT                            -HTML */
+  "Texte original de ce message",          /* MSG_TXT_VERSION                          -HTML */
+  "Ce message a &eacute;t&eacute; supprim par filtrage",    /* MSG_FILTERED_OUT -HTML */
+  "Auteur",                                /* MSG_FROM              -HTML*/
+  NULL,                                    /* End Of Message Table  - NOWHERE*/
 };
 
 /*
@@ -950,6 +1086,7 @@ char *is[] = {       /* Icelandic */
   "(deleted message)", /* MSG_DEL_SHORT                            -HTML */
   "Original text of this message", /* MSG_TXT_VERSION                          -HTML */
   "This message has been filtered out",        /* MSG_FILTERED_OUT -HTML */
+  "Hfundur",                         /* MSG_FROM              -HTML*/
   NULL,                               /* End Of Message Table      - NOWHERE*/
 };
 
@@ -958,7 +1095,7 @@ char *is[] = {       /* Icelandic */
 ** (a little secret for free: we don't say bork ;-)
 */
 
-char *se[] = {
+char *sv[] = {
   "Nytt brev",                      /* New Message        -HTML*/
   "Svar" ,                          /* Reply              -HTML*/
   "Om den hr listan",      /* About this list    -HTML*/
@@ -1083,6 +1220,7 @@ char *se[] = {
   "(borttaget brev)", /* MSG_DEL_SHORT                            -HTML */
   "Ursprunglig brevtext", /* MSG_TXT_VERSION                          -HTML */
   "This message has been filtered out",        /* MSG_FILTERED_OUT -HTML */
+  "Frfattare",                     /* MSG_FROM             -HTML*/
   NULL,                             /* End Of Message Table    - NOWHERE*/
 };
 
@@ -1091,13 +1229,14 @@ char *se[] = {
 */
 
 struct language_entry ltable[] = {
-{    "de",      de   },     /* German  */
-{    "en",      en   },     /* English */
-{    "es",      es   },     /* Spanish */
-{    "fi",      fi   },     /* Finnish */
-{    "fr",      fr   },     /* French  */
-{    "is",      is   },     /* Icelandic */
-{    "se",      se   },     /* Swedish */
+{    "de",      de,    "de_DE"   },     /* German  */
+{    "en",      en,    "en_US"   },     /* English */
+{    "es",      es,    "es_ES"   },     /* Spanish */
+{    "fi",      fi,    "fi_FI"   },     /* Finnish */
+{    "fr",      fr,    "fr_FR"   },     /* French  */
+{    "is",      is,    "is_IS"   },     /* Icelandic */
+{    "pl",      pl,    "pl_PL"   },     /* Polish  */
+{    "sv",      sv,    "sv_SE"   },     /* Swedish */
 {     NULL,     NULL },     /* EOL     */
 };
 
