@@ -78,6 +78,12 @@ static int hasblack(char *p)
 
 int ignorecontent(char *type)
 {
+    if (inlist(set_ignore_types, "$NONPLAIN") && !textcontent(type)
+	&& strncasecmp(type, "multipart/", 10))
+      return 1;
+    if (inlist(set_ignore_types, "$BINARY") && !textcontent(type)
+	&& strcasecmp(type, "text/html") && strncasecmp(type, "multipart/", 10))
+      return 1;
     return (inlist(set_ignore_types, type));
 }
 
@@ -93,6 +99,9 @@ int preferedcontent(int *current_weight, char *type)
 
     status = 0;
 
+    if (set_save_alts == 1)
+	return 1;
+
     /* We let plain text remain PREFERED at all times */
     if (!strcasecmp("text/plain", type)) {
 	if (*current_weight != 0) {
@@ -241,23 +250,6 @@ void print_progress(int num, char *msg, char *filename)
     fflush(stdout);
 }
 
-char *tmpname(char *dir, char *pfx)
-{
-    char *f, *name;
-    static int cntr = 0;
-
-    trio_asprintf(&name, "%s/%s%dXXXXXX", dir, pfx, cntr++);
-    if (NULL == name)
-	return (NULL);
-
-    if ((f = mktemp(name)) != NULL)
-	return (f);
-
-    /* this means failure: */
-    free(name);
-    return (NULL);
-}
-
 char *safe_filename(char *name)
 {
     register char *sp;
@@ -272,9 +264,10 @@ char *safe_filename(char *name)
 
     for (sp = name, np = name; *np && *np != '\n';) {
 	/* if valid character then store it */
-	if ((*np >= 'a' && *np <= 'z') || (*np >= '0' && *np <= '9') ||
-	    (*np >= 'A' && *np <= 'Z') || (*np == '-') || (*np == '.') ||
-	    (*np == ':') || (*np == '_')) {
+	if (((*np >= 'a' && *np <= 'z') || (*np >= '0' && *np <= '9') ||
+	     (*np >= 'A' && *np <= 'Z') || (*np == '-') || (*np == '.') ||
+	     (*np == ':') || (*np == '_'))
+	    && !(set_unsafe_chars && strchr(set_unsafe_chars, *np))) {
 	    *sp = *np;
 	}
 	else	/* Need to replace the character with a safe one */
@@ -283,6 +276,8 @@ char *safe_filename(char *name)
 	np++;
     }
     *sp = '\0';
+    if (sp >= name + 6 && !strcmp(sp - 6, ".shtml"))
+	strcpy(sp - 6, ".html");
 
     return name;
 }
@@ -1034,8 +1029,9 @@ static void write_txt_file(struct emailinfo *emp, struct Push *raw_text_buf)
     char tmp_buf[32];
     sprintf(tmp_buf, "%.4d", emp->msgnum);
     txt_filename = htmlfilename(tmp_buf, emp, set_txtsuffix);
-    if ((!emp->is_deleted || (emp->is_deleted == 1 && set_delete_level > 2)
-	 || (emp->is_deleted == 2 && set_delete_level == 2))
+    if ((!emp->is_deleted
+	 || (emp->is_deleted == FILTERED_DELETE && set_delete_level > 2)
+	 || (emp->is_deleted == FILTERED_EXPIRE && set_delete_level == 2))
 	&& (set_overwrite || !isfile(txt_filename))) {
         FILE *fp = fopen(txt_filename, "w");
 	if (fp) {
@@ -1236,7 +1232,7 @@ int parsemail(char *mbox,	/* file name */
 	line = line_buf + set_ietf_mbox; 
 	if (!is_deleted &&
 	    inlist_regex_pos(set_filter_out_full_body, line) != -1) {
-	    is_deleted = 4;
+	    is_deleted = FILTERED_OUT;
 	}
 	pos = inlist_regex_pos(set_filter_require_full_body, line);
 	if (pos != -1 && pos < require_filter_full_len) {
@@ -1248,7 +1244,8 @@ int parsemail(char *mbox,	/* file name */
 	    /* check for MIME */
 	    else if (!strncasecmp(line, "MIME-Version:", 13))
 		Mime_B = TRUE;
-	    else if (isspace(line[0]) && ('\n' != line[0])) {
+	    else if (isspace(line[0]) && ('\n' != line[0]) \
+		     && !('\r' == line[0] && '\n' == line[1])) {
 		/*
 		 * since this begins with a whitespace, it means the 
 		 * previous line is continued on this line, leave only 
@@ -1264,7 +1261,7 @@ int parsemail(char *mbox,	/* file name */
 			    BODY_CONTINUE | BODY_HEADER | bodyflags);
 	    }
 
-	    else if (line[0] == '\n') {
+	    else if (line[0] == '\n' || (line[0] == '\r' && line[1] == '\n')) {
 		struct body *head;
 
 		char savealternative;
@@ -1305,7 +1302,7 @@ int parsemail(char *mbox,	/* file name */
 		    if (inlist(set_deleted, head_name)) {
 		        char *val = getsubject(head->line); /* revisit me */
 			if (!strcasecmp(val, "yes"))
-			    is_deleted = 1;
+			    is_deleted = FILTERED_DELETE;
 			free(val);
 		    }
 
@@ -1313,13 +1310,13 @@ int parsemail(char *mbox,	/* file name */
 		        char *val = getmaildate(head->line);
 			exp_time = convtoyearsecs(val);
 			if (exp_time != -1 && exp_time < time(NULL))
-			    is_deleted = 2;
+			    is_deleted = FILTERED_EXPIRE;
 			free(val);
 		    }
 
 		    if (!is_deleted &&
 			inlist_regex_pos(set_filter_out, head->line) != -1) {
-		        is_deleted = 4;
+		        is_deleted = FILTERED_OUT;
 		    }
 
 		    pos = inlist_regex_pos(set_filter_require, head->line);
@@ -1404,27 +1401,33 @@ int parsemail(char *mbox,	/* file name */
 			    && (content != CONTENT_IGNORE)) {
 			    /* signal we want to attach, rather than embeed this MIME 
 			       attachment */
-			    attach_force = TRUE;
-
-			    /* make sure it is binary */
-			    content = CONTENT_BINARY;
-
-			    /* see if there's a file name to use: */
-			    fname = strcasestr(ptr, "filename=");
-			    if (fname) {
-                                np = fname+9;
-                                if (*np == '"')
-                                     np++;
-                                for (jp = attachname; np && *np != '\n' && *np != '"';) {
-                                     *jp++ = *np++;
-                                }
-                                *jp = '\0';
-				safe_filename(attachname);
-			    }
+			    if (inlist(set_ignore_types, "$NONPLAIN")
+				|| inlist(set_ignore_types, "$BINARY"))
+			        content = CONTENT_IGNORE;
 			    else {
-				attachname[0] = '\0';	/* just clear it */
+				attach_force = TRUE;
+
+				/* make sure it is binary */
+				content = CONTENT_BINARY;
+
+				/* see if there's a file name to use: */
+				fname = strcasestr(ptr, "filename=");
+				if (fname) {
+                                    np = fname+9;
+				    if (*np == '"')
+                                	np++;
+				    for (jp = attachname; np && *np != '\n'
+					   && *np != '"';) {
+                                	*jp++ = *np++;
+				    }
+				    *jp = '\0';
+				    safe_filename(attachname);
+				}
+				else {
+				    attachname[0] = '\0';  /* just clear it */
+				}
+				file_created = MAKE_FILE; /* please make one */
 			    }
-			    file_created = MAKE_FILE;	/* please make one */
 			}
 #if 0
 /*
@@ -1519,6 +1522,8 @@ int parsemail(char *mbox,	/* file name */
 				    alternative_lastfile[0] = '\0';
 				}
 			    }
+			    else if (set_save_alts == 2)
+				content = CONTENT_BINARY;
 			    else {
 				/* ...and this type is not a prefered one. Thus, we
 				 * shall ignore it completely! */
@@ -1562,7 +1567,15 @@ int parsemail(char *mbox,	/* file name */
 			    /* text content or text/html follows.
 			     */
 
-			    if (!strcasecmp(type, "text/html"))
+			    if (set_save_alts && alternativeparser
+				&& content == CONTENT_BINARY) {
+				file_created = MAKE_FILE; /* please make one */
+				description = set_alts_text ? set_alts_text
+				  : "alternate version of message";
+				strcpy(attachname, description);
+				safe_filename(attachname);
+			    }
+			    else if (!strcasecmp(type, "text/html"))
 				content = CONTENT_HTML;
 			    else
 				content = CONTENT_TEXT;
@@ -1582,7 +1595,7 @@ int parsemail(char *mbox,	/* file name */
 			     * be used.
 			     */
 			    bp = addbody(bp, &lp,
-					 "<p><strong>attached mail follows:</strong><hr noshade>",
+					 "<p><strong>attached mail follows:</strong><hr>",
 					 BODY_HTMLIZED | bodyflags);
 			    bodyflags |= BODY_ATTACHED;
 			    /* @@ should it be 1 or 2 ?? should we use another method? */
@@ -1628,7 +1641,9 @@ int parsemail(char *mbox,	/* file name */
 			     */
 
 			    boundary = strcasestr(ptr, "boundary=");
-
+#if DEBUG_PARSE
+			    printf("boundary found in %s\n", ptr);
+#endif
 			    if (boundary) {
 				boundary = strchr(boundary, '=');
 				if (boundary) {
@@ -1645,13 +1660,35 @@ int parsemail(char *mbox,	/* file name */
 				    boundary = boundbuffer;
 				}
 
+				/* let's remember 'bp' and 'lp' */
+				origbp = bp;
+				origlp = lp;
+				/* restart on a new list: */
+				lp = bp = NULL;
+
 				while (fgets(line_buf, MAXLINE, fp)) {
 				    if (!strncmp(line_buf + set_ietf_mbox, "--", 2) &&
 					!strncmp(line_buf + set_ietf_mbox + 2, boundbuffer,
 						 strlen(boundbuffer))) {
 					break;
 				    }
+				    if (!strncasecmp(line_buf, "From ", 5)) {
+				        isinheader = 0;
+#if DEBUG_PARSE
+					printf("Error, new message found instead of boundary!\n");
+#endif
+					origbp = append_body(origbp, &origlp, bp);
+					bp = origbp;
+					lp = origlp;
+					boundary = NULL;
+					goto leave_header;
+				    }
+				    /* save lines in case no boundary found */
+				    bp = addbody(bp, &lp, line_buf, bodyflags);
 				}
+				free_body(bp);
+				bp = origbp;
+				lp = origlp;
 
 				/* 
 				 * This stores the boundary string in a stack 
@@ -1809,7 +1846,7 @@ int parsemail(char *mbox,	/* file name */
 	else {
 
 	    /* not in header */
-
+	leave_header:
 	    /* If this isn't a single mail: see if the line is a message
 	     * separator. If there is a "^From " found, check to see if there
 	     * is a valid date field in the line. If not then consider it a
@@ -1981,25 +2018,7 @@ int parsemail(char *mbox,	/* file name */
 #if DEBUG_PARSE
 				printf("We DUMP the chosen alternative\n");
 #endif
-				while (bp) {
-				    origbp = addbody(origbp, &origlp,
-						     bp->line,
-						     (bp->
-						      header ? BODY_HEADER
-						      : 0) | (bp->
-							      html ?
-							      BODY_HTMLIZED
-							      : 0) | (bp->
-								      attached
-								      ?
-								      BODY_ATTACHED
-								      : 0)
-					);
-				    next = bp->next;
-				    free(bp->line);
-				    free(bp);
-				    bp = next;
-				}
+				origbp = append_body(origbp, &origlp, bp);
 				bp = origbp;
 				lp = origlp;
 
@@ -2013,7 +2032,7 @@ int parsemail(char *mbox,	/* file name */
 #endif
 			}
 			else {
-			    if (alternativeparser) {
+			    if (alternativeparser && !set_save_alts) {
 				/*
 				 * parsing another alternative, so we save the
 				 * precedent values 
@@ -2028,8 +2047,18 @@ int parsemail(char *mbox,	/* file name */
 				headp = bp = lp = NULL;
 				alternative_file[0] = '\0';
 			    }
-			    else
+			    else {
 				att_counter++;
+				if (alternativeparser && set_save_alts == 1) {
+				    bp = addbody(bp, &lp,
+						 set_alts_text ? set_alts_text
+						 : "<hr>",
+						 BODY_HTMLIZED | bodyflags);
+				}
+			    }
+#if DEBUG_PARSE
+			    printf("mime parsing isinheader set to 1\n");
+#endif
 			    isinheader = 1;	/* back on a kind-of-header */
 			    /* @@@ why are we changing the status of this variable? */
 			    file_created = NO_FILE;	/* not created any file yet */
@@ -2280,15 +2309,16 @@ int parsemail(char *mbox,	/* file name */
 
 				    if (description && description[0] != '\0'
                                         && hasblack(description))
-                                            desc = description;
+                                            desc = convchars(description);
 				    else if (inline_force ||
-					     inlinecontent(type)) desc =
-					    attachname[0] ? attachname :
-					    "picture";
+					     inlinecontent(type))
+				        desc =
+					    attachname[0] ? attachname
+					    : "picture";
 				    else
 					desc =
-					    attachname[0] ? attachname :
-					    "stored";
+					    attachname[0] ? attachname
+					    : "stored";
 
 				    if (description)
 					description = NULL;
@@ -2308,7 +2338,7 @@ int parsemail(char *mbox,	/* file name */
 
 					trio_snprintf(buffer, sizeof(buffer),
 						 "%s<img src=\"%s%s%c%s\" alt=\"%s\">\n",
-						 (set_showhr ? "<hr noshade>\n" :
+						 (set_showhr ? "<hr>\n" :
 						  ""),
 						 subdir ? subdir->rel_path_to_top : "",
 						 &att_dir[strlen(dir) + 1],
@@ -2327,7 +2357,7 @@ int parsemail(char *mbox,	/* file name */
 
 					trio_snprintf(buffer, sizeof(buffer),
 						 "%s<ul>\n<li>%s %s: <a href=\"%s%s\">%s</a>\n</ul>\n",
-						 (set_showhr ? "<hr noshade>\n" :
+						 (set_showhr ? "<hr>\n" :
 						  ""), type,
 						 lang[MSG_ATTACHMENT],
 						 subdir ? subdir->rel_path_to_top : "",
@@ -2520,7 +2550,6 @@ int parsemail(char *mbox,	/* file name */
     return num_added;			/* amount of mails read */
 }
 
-
 int parse_old_html(int num, struct emailinfo *ep, int parse_body,
 		   int do_insert, struct reply **replylist_tmp)
 {
@@ -3124,7 +3153,7 @@ void fixnextheader(char *dir, int num, int direction)
 	while (bp) {
 	    fprintf(fp, "%s", bp->line);
 	    if (!strncmp(bp->line, "<!-- next=", 10)) {
-		email = neighborlookup(num, 1);
+		email = neighborlookup(num-1, 1);
 		if (email != NULL) {
 		    if (set_usetable) {
 			dp = bp->next;
@@ -3152,14 +3181,7 @@ void fixnextheader(char *dir, int num, int direction)
     fclose(fp);
 
     /* can we clean up a bit please... */
-    bp = cp;
-    while (bp != NULL) {
-	cp = bp->next;
-	if (bp->line)
-	    free(bp->line);
-	free(bp);
-	bp = cp;
-    }
+    free_body(cp);
     free(filename);
 }
 
@@ -3168,12 +3190,12 @@ void fixnextheader(char *dir, int num, int direction)
 ** incrementally updated.
 */
 
-void fixreplyheader(char *dir, int num, int remove_maybes)
+void fixreplyheader(char *dir, int num, int remove_maybes, int max_update)
 {
     char *filename;
     char line[MAXLINE];
 
-    int subjmatch;
+    int subjmatch = 0;
     int replynum = -1;
 
     struct body *bp, *cp, *status;
@@ -3239,6 +3261,8 @@ void fixreplyheader(char *dir, int num, int remove_maybes)
 	    return;
 	replynum = email2->msgnum;
     }
+    if (replynum >= max_update)	/* was created this session, must be current */
+	return;
 
     if (email2 == NULL)
 	hashnumlookup(replynum, &email2);
@@ -3274,24 +3298,18 @@ void fixreplyheader(char *dir, int num, int remove_maybes)
 	while (bp) {
 	    if (!strncmp(bp->line, "<!-- reply", 10)) {
 	        char *del_msg = (email2->is_deleted ? lang[MSG_DEL_SHORT] : "");
-	        if (last_reply) {
-		  char buf1[MAXLINE];
-		  ptr = convchars(email->subject);
-		  sprintf(buf1,
-			  "<li><strong>%s:</strong>%s %s%s: \"%s\"</a>\n",
-			  lang[MSG_REPLY], del_msg, msg_href(email, email2),
-			  email->name, ptr);
+		char *ptr1;
+		ptr = convchars(email->subject);
+		trio_asprintf(&ptr1,
+			      "<li><strong>%s:</strong>%s %s%s: \"%s\"</a>\n",
+			      lang[subjmatch ? MSG_MAYBE_REPLY : MSG_REPLY],
+			      del_msg, msg_href(email, email2),
+			      email->name, ptr);
+		free(ptr);
 
-		  if (strcmp(buf1, last_reply))
-		      fputs(buf1, fp);
-		}
-		else {
-		    fprintf(fp, "<li><strong>%s:</strong>", lang[MSG_REPLY]);
-		    fprintf(fp, "%s %s", del_msg, msg_href(email, email2));
-		    fprintf(fp, "%s: \"%s\"</a>\n", email->name,
-			    ptr = convchars(email->subject));
-		    free(ptr);
-		}
+		if (!last_reply || strcmp(ptr1, last_reply))
+		    fputs(ptr1, fp);
+		free(ptr1);
 	    }
 	    if (next_in_thread - 1 == replynum
 		&& (strcasestr(bp->line, current_next_pattern)
@@ -3312,14 +3330,7 @@ void fixreplyheader(char *dir, int num, int remove_maybes)
     fclose(fp);
 
     /* can we clean up a bit please... */
-    bp = cp;
-    while (bp) {
-	cp = bp->next;
-	if (bp->line)
-	    free(bp->line);
-	free(bp);
-	bp = cp;
-    }
+    free_body(cp);
     free(filename);
 }
 
@@ -3328,7 +3339,7 @@ void fixreplyheader(char *dir, int num, int remove_maybes)
 ** has been incrementally updated.
 */
 
-void fixthreadheader(char *dir, int num)
+void fixthreadheader(char *dir, int num, int max_update)
 {
     char *filename;
     char line[MAXLINE];
@@ -3354,7 +3365,7 @@ void fixthreadheader(char *dir, int num)
 	}
     }
 
-    if (rp == NULL)
+    if (rp == NULL || threadnum >= max_update)
 	return;
 
     filename = articlehtmlfilename(rp->data);
@@ -3393,14 +3404,7 @@ void fixthreadheader(char *dir, int num)
     fclose(fp);
 
     /* can we clean up a bit please... */
-    bp = cp;
-    while (bp != NULL) {
-	cp = bp->next;
-	if (bp->line)
-	    free(bp->line);
-	free(bp);
-	bp = cp;
-    }
+    free_body(cp);
     free(filename);
 }
 
