@@ -183,8 +183,11 @@ void fprint_menu(FILE *fp, mindex_t idx, char *archives, char *currentid,
     int dlev = (subdir != NULL);
     int i;
     int count_l = 0;
+#if DEBUG_HTML
+    printcomment(fp, "fprint_menu", "begin");
+#endif
     fprintf(fp,
-	    "<div align=\"center\">\n<table border=\"2\" width=\"100%%\">\n<tr>\n");
+	    "<div class=\"center\">\n<table border=\"2\" width=\"100%%\">\n<tr>\n");
 
     if (set_mailcommand) {
 	if (set_hmail) {
@@ -267,13 +270,19 @@ void fprint_menu(FILE *fp, mindex_t idx, char *archives, char *currentid,
 		lang[MSG_OTHER_MAIL_ARCHIVES]);
 
     fprintf(fp, "</tr>\n</table>\n</div>\n");
+#if DEBUG_HTML
+    printcomment(fp, "fprint_menu", "end");
+#endif
 }
 
 /*----------------------------------------------------------------------------*/
 
 void fprint_summary(FILE *fp, int pos, long first_d, long last_d, int num)
 {
-    fprintf(fp, "<div align=\"center\">\n");
+#if DEBUG_HTML
+    printcomment(fp, "fprint_summary", "begin");
+#endif
+    fprintf(fp, "<div class=\"center\">\n");
     fprintf(fp, "<table>\n");
 
     if (pos == PAGE_TOP) {
@@ -291,6 +300,9 @@ void fprint_summary(FILE *fp, int pos, long first_d, long last_d, int num)
                 lang[MSG_ARCHIVED_ON], getlocaltime());
     }
     fprintf(fp, "</table>\n</div>\n");
+#if DEBUG_HTML
+    printcomment(fp, "fprint_summary", "end");
+#endif
 }
 
 /*----------------------------------------------------------------------------*/
@@ -312,6 +324,10 @@ void print_index_header_links(FILE *fp, mindex_t called_from,
     char *ptr;
     int dlev = (subdir != NULL);
 
+#if DEBUG_HTML
+    printcomment(fp, "index_header_links", "begin");
+#endif
+    fprintf(fp, "<p>\n");
     if (set_mailcommand && set_hmail) {
 	ptr = makemailcommand("mailto:$TO", set_hmail, "", "");
 	fprintf(fp, "<strong><a href=\"%s\">%s</A></strong>\n",
@@ -324,10 +340,10 @@ void print_index_header_links(FILE *fp, mindex_t called_from,
 	fprintf(fp, "<strong><a href=\"#end\">%s</a></strong><br>\n",
 		lang[MSG_MOST_RECENT_MESSAGES]);
 
-    if (called_from != AUTHOR_INDEX && show_index[dlev][AUTHOR_INDEX] ||
-        called_from != DATE_INDEX &&  show_index[dlev][DATE_INDEX] ||
-        called_from != THREAD_INDEX && show_index[dlev][THREAD_INDEX] ||
-        called_from != SUBJECT_INDEX && show_index[dlev][SUBJECT_INDEX])
+    if ((called_from != AUTHOR_INDEX && show_index[dlev][AUTHOR_INDEX]) ||
+        (called_from != DATE_INDEX &&  show_index[dlev][DATE_INDEX]) ||
+        (called_from != THREAD_INDEX && show_index[dlev][THREAD_INDEX]) ||
+        (called_from != SUBJECT_INDEX && show_index[dlev][SUBJECT_INDEX]))
            fprintf(fp, "<strong>%d %s %s:</strong> \n", amountmsgs,
                lang[MSG_ARTICLES], lang[MSG_SORTED_BY]);
 
@@ -394,24 +410,25 @@ void print_index_header_links(FILE *fp, mindex_t called_from,
 	    free(ptr);
     }
 
-
-#if 0 /* JK removed this */
-    fprintf(fp, "<p>\n");
-#endif
-    /* JK: added a <p> */
     if (set_showhr)
-        fprintf(fp, "<hr noshade><p>\n");
+        fprintf(fp, "</p><hr>\n");
+    else
+        fprintf(fp, "</p>\n");
 
     /*
      * Printout the Dates for the Starting and Ending messages 
      * in the archive, along with a count of the messages.
      */
-
+    fprintf(fp, "<p>\n");
     fprintf(fp, "<strong>%s:</strong> <em>%s</em><br>\n",
             lang[MSG_STARTING], getdatestr(startdatenum));
 
     fprintf(fp, "<strong>%s:</strong> <em>%s</em><br>\n",
             lang[MSG_ENDING], getdatestr(enddatenum));
+    fprintf(fp, "</p>\n");
+#if DEBUG_HTML
+    printcomment(fp, "index_header_links", "end");
+#endif
 }
 
 void print_index_footer_links(FILE *fp, mindex_t called_from,
@@ -429,20 +446,26 @@ void print_index_footer_links(FILE *fp, mindex_t called_from,
      char *ptr;
      int dlev = (subdir != NULL);
 
-     fprintf(fp, "<a name=\"end\"><strong>%s:</strong></a> <em>%s</em><br>\n",
+#if DEBUG_HTML
+    printcomment(fp, "index_footer_links", "begin");
+#endif
+    fprintf(fp, "<p>\n");
+    fprintf(fp, "<a name=\"end\"><strong>%s:</strong></a> <em>%s</em><br>\n",
 		lang[MSG_LAST_MESSAGE_DATE], getdatestr(lastdatenum));
 
-     fprintf(fp, "<strong>%s:</strong> <em>%s</em><p>\n",
-             lang[MSG_ARCHIVED_ON], getlocaltime());
+    fprintf(fp, "<strong>%s:</strong> <em>%s</em>\n",
+                lang[MSG_ARCHIVED_ON], getlocaltime());
 
-     if (set_showhr)
-         fprintf(fp, "<hr noshade>\n");
+    if (set_showhr)
+        fprintf(fp, "</p><hr>\n");
+    else
+        fprintf(fp, "</p>\n");
 
-    fprintf(fp, "\n");
-    if (called_from != AUTHOR_INDEX && show_index[dlev][AUTHOR_INDEX] ||
-        called_from != DATE_INDEX &&  show_index[dlev][DATE_INDEX] ||
-        called_from != THREAD_INDEX && show_index[dlev][THREAD_INDEX] ||
-        called_from != SUBJECT_INDEX && show_index[dlev][SUBJECT_INDEX])
+    fprintf(fp, "<p>\n");
+    if ((called_from != AUTHOR_INDEX && show_index[dlev][AUTHOR_INDEX]) ||
+        (called_from != DATE_INDEX &&  show_index[dlev][DATE_INDEX]) ||
+        (called_from != THREAD_INDEX && show_index[dlev][THREAD_INDEX]) ||
+        (called_from != SUBJECT_INDEX && show_index[dlev][SUBJECT_INDEX]))
            fprintf(fp, "<strong>%d %s %s:</strong> \n", amountmsgs,
                lang[MSG_ARTICLES], lang[MSG_SORTED_BY]);
 
@@ -508,7 +531,10 @@ void print_index_footer_links(FILE *fp, mindex_t called_from,
 	if (ptr)
 	    free(ptr);
     }
-    fprintf(fp, "\n\n");
+    fprintf(fp, "</p>\n");
+#if DEBUG_HTML
+    printcomment(fp, "index_footer_links", "end");
+#endif
 }
 
 /*
@@ -565,7 +591,6 @@ void printhtml(FILE *fp, char *line)
 /*
 ** Pretty-prints the dates in the index files.
 */
-
 void printdates(FILE *fp, struct header *hp, int year, int month,
 	       struct emailinfo *subdir_email)
 {
@@ -600,7 +625,7 @@ void printdates(FILE *fp, struct header *hp, int year, int month,
 	startline = "<li>";
 	break_str = "&nbsp;";
 	sprintf(date_str, "<em>(%s)</em>", getdatestr(hp->data->date));
-	endline = "";
+	endline = "</li>";
 	subj_tag = "<strong>";
 	subj_end_tag = "</strong>";
       }
@@ -617,7 +642,6 @@ void printdates(FILE *fp, struct header *hp, int year, int month,
 /*
 ** Pretty-prints the files with attachments in the index files.
 */
-
 void printattachments(FILE *fp, struct header *hp,
 		      struct emailinfo *subdir_email)
 {
@@ -856,9 +880,6 @@ void printbody(FILE *fp, struct emailinfo *email, int maybe_reply)
     char *id = email->msgid;
     char *subject = email->subject;
     int msgnum = email->msgnum;
-#ifdef REMOVED_19991103
-    int inhtml;
-#endif
     char inheader = FALSE;	/* we always start in a mail header */
     int pre = FALSE;
 
@@ -872,11 +893,10 @@ void printbody(FILE *fp, struct emailinfo *email, int maybe_reply)
       printf("\nMessage %d quoted text (%d %%) replaced by links\n",
 	     msgnum,quoted_percent);
 
-    /* JK: added an extra <p> here */
     if (set_showhr)
-	fprintf(fp, "<hr noshade><p>\n");
-
+	fprintf(fp, "<hr>\n");
     printcomment(fp, "body", "start");
+
     if (email->is_deleted && set_delete_level != DELETE_LEAVES_TEXT
 	&& !(email->is_deleted == 2
 	     && set_delete_level == DELETE_LEAVES_EXPIRED_TEXT)) {
@@ -885,9 +905,10 @@ void printbody(FILE *fp, struct emailinfo *email, int maybe_reply)
 	if (email->is_deleted == 4 || email->is_deleted == 8)
 	    d_index = MSG_FILTERED_OUT;
         fprintf(fp, lang[d_index]);
+	fprintf(fp, "</p>\n");
 	printcomment(fp, "body", "end");
 	if (set_showhr)
-	    fprintf(fp, "<hr noshade>\n");
+	    fprintf(fp, "<hr>\n");
 	return;
     }
 
@@ -896,10 +917,6 @@ void printbody(FILE *fp, struct emailinfo *email, int maybe_reply)
 	pre = TRUE;
     }
 
-#if DEBUG_PRINTBODY
-    else
-	printf("SHOWHTML is ON\n");
-#endif
     if (set_showhtml == 2)
       init_txt2html();
     inquote = 0;
@@ -908,10 +925,6 @@ void printbody(FILE *fp, struct emailinfo *email, int maybe_reply)
     inblank = 1;
     insig = 0;
 
-#ifdef REMOVED_19991103
-    inhtml = 0;
-#endif
-
     while (bp != NULL) {
 	if (bp->html) {
 	    /* already in HTML, don't touch */
@@ -966,17 +979,6 @@ void printbody(FILE *fp, struct emailinfo *email, int maybe_reply)
 	    }
 	}
 
-#ifdef REMOVED_990310
-	if (bp->attached && bp->header) {
-            /* only show <br> if not in <pre> since 
-             * in <pre> mode, the existing newlines are enough! 
-             */
-	    fprintf(fp, "%s%s", bp->line, pre ? "" : "<br>\n");	
-	    bp = bp->next;
-	    continue;
-	}
-#endif
-
 	if (((bp->line)[0] != '\n') && (bp->header && !set_showheaders)) {
 	    bp = bp->next;
 	    continue;
@@ -1000,43 +1002,6 @@ void printbody(FILE *fp, struct emailinfo *email, int maybe_reply)
 	else
 	    inblank = 0;
 
-#ifdef REMOVED_19991103
-	if (!strncasecmp(bp->line, "<html>", 6)) {
-	    inhtml = 1;
-	    if (!set_showhtml && pre) {
-		fprintf(fp, "</pre>\n");
-		pre = FALSE;
-	    }
-	}
-	else if (!strncasecmp(bp->line, "</html>", 7)) {
-	    inhtml = 0;
-	    if (set_showhtml)
-		fprintf(fp, "%s", bp->line);
-	    else {
-		char *ptr;
-		fprintf(fp, "%s<br>", ptr = convchars(bp->line));
-		free(ptr);
-	    }
-	    if (!set_showhtml && !pre) {
-		fprintf(fp, "<pre>\n");
-		pre = TRUE;
-	    }
-	    bp = bp->next;
-	    continue;
-	}
-
-	if (inhtml) {
-	    if (set_showhtml)
-		fprintf(fp, "%s", bp->line);
-	    else {
-		char *ptr;
-		fprintf(fp, "%s<br>", ptr = convchars(bp->line));
-		free(ptr);
-	    }
-	    bp = bp->next;
-	    continue;
-	}
-#endif
 	if (set_showhtml) {
 	    if (is_sig_start(bp->line)) {
 		insig = 1;
@@ -1126,10 +1091,9 @@ void printbody(FILE *fp, struct emailinfo *email, int maybe_reply)
     else if (set_showhtml == 2)
         end_txt2html(fp);
 
-    fprintf(fp, "<p>");
     printcomment(fp, "body", "end");
     if (set_showhr)
-	fprintf(fp, "<hr noshade>\n");
+	fprintf(fp, "<hr>\n");
 }
 
 char *
@@ -1331,22 +1295,18 @@ void writearticles(int startnum, int maxnum)
 	if (set_usetable) {
 	    fprint_menu(fp, NO_INDEX, "",
 			email->msgid, email->subject, PAGE_TOP, email->subdir);
-	    fprintf(fp, "<p>\n");
 	}
 
 	/*
 	 * Print the message's author info and date.
 	 */
-
-#if 0 /* JK: removed it because it's redundant with the H1 header */
-	fprintf(fp, "<strong>Subject: </strong>%s<br>\n", email->subject);
-#endif
+	fprintf(fp, "<p>\n");
 	if (!strcmp(email->name, email->emailaddr)) {
 	    if (use_mailcommand) {
 		ptr = makemailcommand(set_mailcommand,
 				      email->emailaddr,
 				      email->msgid, email->subject);
-		fprintf(fp, "<strong>From:</strong> <a href=\"%s\">", ptr ? ptr : "");
+		fprintf(fp, "<strong>%s:</strong> <a href=\"%s\">", lang[MSG_FROM], ptr ? ptr : "");
 		if (ptr)
 		    free(ptr);
 		fprintf(fp, "<em>%s</em></a><br>\n", email->name);
@@ -1359,8 +1319,8 @@ void writearticles(int startnum, int maxnum)
 		ptr = makemailcommand(set_mailcommand,
 				      email->emailaddr,
 				      email->msgid, email->subject);
-		fprintf(fp, "<strong>From:</strong> %s (<a href=\"%s\">",
-			email->name, ptr ? ptr : "");
+		fprintf(fp, "<strong>%s:</strong> %s (<a href=\"%s\">",
+			lang[MSG_FROM], email->name, ptr ? ptr : "");
 		if (ptr)
 		    free(ptr);
 		fprintf(fp, "<em>%s</em></a>)<br>\n", email->emailaddr);
@@ -1368,13 +1328,14 @@ void writearticles(int startnum, int maxnum)
 	    else
 	    {
 		fprintf(fp,
-			"<strong>From:</strong> %s (<em>%s</em>)<br>\n",
-			email->name, 
+			"<strong>%s:</strong> %s (<em>%s</em>)<br>\n",
+			lang[MSG_FROM], email->name, 
 			(strcmp(email->emailaddr,"(no email)")!=0) ? email->emailaddr : "no email");
 	    }
 	}
-	fprintf(fp, "<strong>Date:</strong> %s\n<p>\n",
+	fprintf(fp, "<strong>%s:</strong> %s\n", lang[MSG_CDATE],
 		getdatestr(email->date));
+	fprintf(fp, "</p>\n");
 
 	/*
 	 * This is here because it looks better here. The table looks
@@ -1450,9 +1411,7 @@ void writearticles(int startnum, int maxnum)
 	    /*
 	     * Is there a message next in the thread?
 	     */
-
 	    printcomment(fp, "nextthread", "start");
-
 	    if (email_next_in_thread) {
 		fprintf(fp, "<li><strong>%s:</strong> ",
 			lang[MSG_NEXT_IN_THREAD]);
@@ -1571,9 +1530,7 @@ void writearticles(int startnum, int maxnum)
 	if (set_show_msg_links && set_show_msg_links != 3) {
 	  /* JK: removed a <p>\n here */
 	    fprintf(fp, "<ul>\n");
-
 	    printcomment(fp, "next", "start");
-
 	    email2 = neighborlookup(num, 1);
 
 	    if (email2 != NULL) {
@@ -1616,9 +1573,7 @@ void writearticles(int startnum, int maxnum)
 		    free(ptr);
 		}
 	    }
-
 	    printcomment(fp, "nextthread", "start");
-
 	    /* email_next_in_thread = nextinthread(email->msgnum); redundant */
 	    if (email_next_in_thread) {
 		fprintf(fp, "<li><strong>%s:</strong> ",
@@ -1658,10 +1613,10 @@ void writearticles(int startnum, int maxnum)
 	        fprintf(fp, "</ul>\n");
 	}
 
-	if (set_usetable)
+	if (set_usetable) {
 	    fprint_menu(fp, NO_INDEX, "", email->msgid, email->subject,
 			PAGE_BOTTOM, email->subdir);
-	else {
+	} else {
 	      int dlev = (email->subdir != NULL);
 	      if (!(set_show_msg_links && set_show_msg_links != 3))
 		  fprintf(fp, "<ul>\n");
@@ -1769,7 +1724,7 @@ void writearticles(int startnum, int maxnum)
 		}
 	    }
 	    if (!was_correct)
-	        fixreplyheader(set_dir, num, TRUE);
+	        fixreplyheader(set_dir, num, TRUE, num);
 	}
 
 	if (newfile && chmod(filename, set_filemode) == -1) {
@@ -1850,9 +1805,8 @@ void writedates(int amountmsgs, struct emailinfo *email)
 	fprint_menu(fp, DATE_INDEX, set_archives, "", "", PAGE_TOP,
 		    email ? email->subdir : NULL);
 	fprint_summary(fp, PAGE_TOP, firstdatenum, lastdatenum, amountmsgs);
-	/* JK: added an extra <p> here */
 	if (set_showhr)
-	    fprintf(fp, "<hr noshade><p>\n"); 
+	    fprintf(fp, "<hr>\n"); 
     }
 
     /*
@@ -1860,7 +1814,7 @@ void writedates(int amountmsgs, struct emailinfo *email)
      */
     if (set_indextable)
 	fprintf(fp,
-		"<div align=\"center\">\n<table width=\"80%%\">\n<tr><td><u><strong>%s</strong></u></td><td><u><strong>%s</strong></u></td><td><u><strong>%s</strong></u></td></tr>\n",
+		"<div class=\"center\">\n<table width=\"80%%\">\n<tr><td><u><strong>%s</strong></u></td><td><u><strong>%s</strong></u></td><td><u><strong>%s</strong></u></td></tr>\n",
 		lang[MSG_CSUBJECT], lang[MSG_CAUTHOR], lang[MSG_CDATE]);
     else
 	fprintf(fp, "<ul>\n");
@@ -1868,9 +1822,9 @@ void writedates(int amountmsgs, struct emailinfo *email)
     printdates(fp, datelist, -1, -1, email);
     
     if (set_indextable)
-	fprintf(fp, "</table>\n</div>\n<p>\n");
+	fprintf(fp, "</table>\n</div>\n");
     else
-	fprintf(fp, "</ul>\n<p>\n");
+	fprintf(fp, "</ul>\n");
 
     if (!set_usetable) {
 	/* 
@@ -1881,7 +1835,7 @@ void writedates(int amountmsgs, struct emailinfo *email)
     }
     else {
 	if (set_showhr)
-	    fprintf(fp, "<hr noshade>\n");
+	    fprintf(fp, "<hr>\n");
 	fprint_summary(fp, PAGE_BOTTOM, firstdatenum, lastdatenum, amountmsgs);
 	fprint_menu(fp, DATE_INDEX, set_archives, "", "", PAGE_BOTTOM,
 		    email ? email->subdir : NULL);
@@ -1947,9 +1901,8 @@ void writeattachments(int amountmsgs, struct emailinfo *email)
     else {
 	fprint_menu(fp, ATTACHMENT_INDEX, set_archives, "", "", PAGE_TOP, NULL);
 	fprint_summary(fp, PAGE_TOP, firstdatenum, lastdatenum, amountmsgs);
-	/* JK: added an extra <p> here */
 	if (set_showhr)
-	    fprintf(fp, "<hr noshade><p>\n"); 
+	    fprintf(fp, "<hr>\n"); 
     }
 
     /*
@@ -1958,29 +1911,29 @@ void writeattachments(int amountmsgs, struct emailinfo *email)
 
     if (set_indextable) {
 	fprintf(fp,
-		"<div align=\"center\">\n<table width=\"80%%\">\n<tr><td><u><strong>%s</strong></u></td><td><u><strong>%s</strong></u></td><td><u><strong>%s</strong></u></td></tr>\n",
+		"<div class=\"center\">\n<table width=\"80%%\">\n<tr><td><u><strong>%s</strong></u></td><td><u><strong>%s</strong></u></td><td><u><strong>%s</strong></u></td></tr>\n",
 		lang[MSG_CSUBJECT], lang[MSG_CAUTHOR], lang[MSG_CDATE]);
 	printattachments(fp, datelist, email);
-	fprintf(fp, "</table>\n</div>\n<p>\n");
+	fprintf(fp, "</table>\n</div>\n");
     }
     else {
 	fprintf(fp, "<ul>\n");
 	printattachments(fp, datelist, email);
-	fprintf(fp, "</ul>\n<p>\n");
+	fprintf(fp, "</ul>\n");
     }
 
     if (!set_usetable) {
 	/* 
 	 * Print out archive information links at the bottom of the index
 	 */
-	print_index_footer_links(fp, DATE_INDEX, lastdatenum, amountmsgs,
+	print_index_footer_links(fp, ATTACHMENT_INDEX, lastdatenum, amountmsgs,
 				 email ? email->subdir : NULL);
     }
     else {
 	if (set_showhr)
-	    fprintf(fp, "<hr noshade>\n");
+	    fprintf(fp, "<hr>\n");
 	fprint_summary(fp, PAGE_BOTTOM, firstdatenum, lastdatenum, amountmsgs);
-	fprint_menu(fp, DATE_INDEX, set_archives, "", "", PAGE_BOTTOM,
+	fprint_menu(fp, ATTACHMENT_INDEX, set_archives, "", "", PAGE_BOTTOM,
 		    email ? email->subdir : NULL);
     }
 
@@ -2052,22 +2005,21 @@ void writethreads(int amountmsgs, struct emailinfo *email)
 	fprint_menu(fp, THREAD_INDEX, set_archives, "", "", PAGE_TOP,
 		    email ? email->subdir : NULL);
 	fprint_summary(fp, PAGE_TOP, firstdatenum, lastdatenum, amountmsgs);
-	/* JK: added an extra <p> here */
 	if (set_showhr)
-	    fprintf(fp, "<hr noshade><p>\n");
+	    fprintf(fp, "<hr>\n");
     }
 
     if (set_indextable) {
 	fprintf(fp,
-		"<div align=\"center\">\n<table>\n<tr><td><u><strong>%s</strong></u></td><td><u><strong>%s</strong></u></td><td><u><strong> %s</strong></u></td></tr>\n",
+		"<div class=\"center\">\n<table>\n<tr><td><u><strong>%s</strong></u></td><td><u><strong>%s</strong></u></td><td><u><strong> %s</strong></u></td></tr>\n",
 		lang[MSG_CSUBJECT], lang[MSG_CAUTHOR], lang[MSG_CDATE]);
 	print_all_threads(fp, -1, -1, email);
-	fprintf(fp, "</table>\n</div>\n<p>\n");
+	fprintf(fp, "</table>\n</div>\n");
     }
     else {
 	fprintf(fp, "<ul>\n");
 	print_all_threads(fp, -1, -1, email);
-	fprintf(fp, "</ul>\n<p>\n");
+	fprintf(fp, "</ul>\n");
     }
 
     if (!set_usetable) {
@@ -2079,7 +2031,7 @@ void writethreads(int amountmsgs, struct emailinfo *email)
     }
     else {
 	if (set_showhr)
-	    fprintf(fp, "<hr noshade>\n");
+	    fprintf(fp, "<hr>\n");
 	fprint_summary(fp, PAGE_BOTTOM, firstdatenum, lastdatenum, amountmsgs);
 	fprint_menu(fp, THREAD_INDEX, set_archives, "", "", PAGE_BOTTOM,
 		    email ? email->subdir : NULL);
@@ -2144,7 +2096,7 @@ void printsubjects(FILE *fp, struct header *hp, char **oldsubject,
 	    startline = "<ul><li>";
 	    break_str = "";
 	    sprintf(date_str, "<em>(%s)</em>", getdatestr(hp->data->date));
-	    endline = "</ul>";
+	    endline = "</li></ul>";
 	}
 	fprintf(fp,
 		"%s%s%s</a>%s <a name=\"%d\">%s</a>%s%s\n", startline,
@@ -2196,14 +2148,13 @@ void writesubjects(int amountmsgs, struct emailinfo *email)
 	fprint_menu(fp, SUBJECT_INDEX, set_archives, "", "", PAGE_TOP,
 		    email ? email->subdir : NULL);
 	fprint_summary(fp, PAGE_TOP, firstdatenum, lastdatenum, amountmsgs);
-	/* JK: added this <p> here */
 	if (set_showhr)
-	    fprintf(fp, "<hr noshade><p>\n");
+	    fprintf(fp, "<hr>\n");
     }
 
     if (set_indextable) {
 	fprintf(fp,
-		"<div align=\"center\">\n<table>\n<tr><td><u><strong>%s</strong></u></td><td><u><strong>%s</strong></u></td><td><u><strong> %s</strong></u></td></tr>\n",
+		"<div class=\"center\">\n<table>\n<tr><td><u><strong>%s</strong></u></td><td><u><strong>%s</strong></u></td><td><u><strong> %s</strong></u></td></tr>\n",
 		lang[MSG_CSUBJECT], lang[MSG_CAUTHOR], lang[MSG_CDATE]);
     }
     else {
@@ -2214,10 +2165,10 @@ void writesubjects(int amountmsgs, struct emailinfo *email)
 	printsubjects(fp, subjectlist, &oldsubject, -1, -1, email);
     }
     if (set_indextable) {
-	fprintf(fp, "</table>\n</div>\n<p>\n");
+	fprintf(fp, "</table>\n</div>\n");
     }
     else {
-	fprintf(fp, "</ul>\n<p>\n");
+	fprintf(fp, "</ul>\n");
     }
 
     /* 
@@ -2229,7 +2180,7 @@ void writesubjects(int amountmsgs, struct emailinfo *email)
 				 email ? email->subdir : NULL);
     else {
 	if (set_showhr)
-	    fprintf(fp, "<hr noshade>\n");
+	    fprintf(fp, "<hr>\n");
 	fprint_summary(fp, PAGE_BOTTOM, firstdatenum, lastdatenum, amountmsgs);
 	fprint_menu(fp, SUBJECT_INDEX, set_archives, "", "", PAGE_BOTTOM,
 		    email ? email->subdir : NULL);
@@ -2294,7 +2245,7 @@ void printauthors(FILE *fp, struct header *hp, char **oldname,
 	startline = "<ul><li>";
 	break_str = "&nbsp;";
 	sprintf(date_str, "<em>(%s)</em>", getdatestr(hp->data->date));
-	endline = "</ul>";
+	endline = "</li></ul>";
       }
       fprintf(fp,"%s%s%s</a>%s<a name=\"%d\">%s</a>%s%s\n",
 	      startline, msg_href(hp->data, subdir_email), subj, break_str,
@@ -2346,14 +2297,13 @@ void writeauthors(int amountmsgs, struct emailinfo *email)
 	fprint_menu(fp, AUTHOR_INDEX, set_archives, "", "", PAGE_TOP,
 		    email ? email->subdir : NULL);
 	fprint_summary(fp, PAGE_TOP, firstdatenum, lastdatenum, amountmsgs);
-	/* JK: added the extra <p> here */
 	if (set_showhr)
-	    fprintf(fp, "<hr noshade><p>\n");
+	    fprintf(fp, "<hr>\n");
     }
 
     if (set_indextable) {
 	fprintf(fp,
-		"<div align=\"center\">\n<table>\n<tr><td><u><strong>%s</strong></u></td><td><u><strong>%s</strong></u></td><td><u><strong> %s</strong></u></td></tr>\n",
+		"<div class=\"center\">\n<table>\n<tr><td><u><strong>%s</strong></u></td><td><u><strong>%s</strong></u></td><td><u><strong> %s</strong></u></td></tr>\n",
 		lang[MSG_CAUTHOR], lang[MSG_CSUBJECT], lang[MSG_CDATE]);
     }
     else {
@@ -2364,10 +2314,10 @@ void writeauthors(int amountmsgs, struct emailinfo *email)
 	printauthors(fp, authorlist, &prevauthor, -1, -1, email);
     }
     if (set_indextable) {
-	fprintf(fp, "</table>\n</div>\n<p>\n");
+	fprintf(fp, "</table>\n</div>\n");
     }
     else {
-	fprintf(fp, "</ul>\n<p>\n");
+	fprintf(fp, "</ul>\n");
     }
 
     /* 
@@ -2380,7 +2330,7 @@ void writeauthors(int amountmsgs, struct emailinfo *email)
 				 email ? email->subdir : NULL);
     else {
 	if (set_showhr)
-	    fprintf(fp, "<hr noshade>\n");
+	    fprintf(fp, "<hr>\n");
 	fprint_summary(fp, PAGE_BOTTOM, firstdatenum, lastdatenum, amountmsgs);
 	fprint_menu(fp, AUTHOR_INDEX, set_archives, "", "", PAGE_BOTTOM,
 		    email ? email->subdir : NULL);
@@ -2490,12 +2440,12 @@ static void printmonths(FILE *fp, char *summary_filename, int amountmsgs)
 		    fprint_summary(fp1, PAGE_TOP, first_date, last_date,
 				   count);
 		    if (set_showhr)
-		        fprintf(fp1, "<hr noshade>\n");
+		        fprintf(fp1, "<hr>\n");
 		}
 
 		if (set_indextable) {
 		    fprintf(fp1,
-			    "<div align=center>\n<table>\n<tr><td><u><strong>%s</strong></u></td><td><u><strong>%s</strong></u></td><td><u><strong> %s</strong></u></td></tr>\n",
+			    "<div class=\"center\">\n<table>\n<tr><td><u><strong>%s</strong></u></td><td><u><strong>%s</strong></u></td><td><u><strong> %s</strong></u></td></tr>\n",
 			    lang[j == AUTHOR_INDEX ? MSG_CAUTHOR : MSG_CSUBJECT],
 			    lang[j == AUTHOR_INDEX ? MSG_CSUBJECT : MSG_CAUTHOR],
 			    lang[MSG_CDATE]);
@@ -2519,10 +2469,10 @@ static void printmonths(FILE *fp, char *summary_filename, int amountmsgs)
 		}
 
 		if (set_indextable) {
-		    fprintf(fp1, "</table>\n</div>\n<p>\n");
+		    fprintf(fp1, "</table>\n</div>\n");
 		}
 		else {
-		    fprintf(fp1, "</ul>\n<p>\n");
+		    fprintf(fp1, "</ul>\n");
 		}
 
 		/* 
@@ -2534,7 +2484,7 @@ static void printmonths(FILE *fp, char *summary_filename, int amountmsgs)
 		    print_index_footer_links(fp1, j, last_date, count, NULL);
 		else {
 		    if (set_showhr)
-		        fprintf(fp1, "<hr noshade>\n");
+		        fprintf(fp1, "<hr>\n");
 		    fprint_summary(fp1, PAGE_BOTTOM, first_date, last_date,
 				   count);
 		    fprint_menu(fp1, j, set_archives, "", "", PAGE_BOTTOM,
@@ -2631,9 +2581,8 @@ void write_toplevel_indices(int amountmsgs)
 	else {
 	    fprint_menu(fp, FOLDERS_INDEX, set_archives, "", "", PAGE_TOP, NULL);
 	    fprint_summary(fp, PAGE_TOP, firstdatenum, lastdatenum, amountmsgs);
-	    /* JK: added an extra <p> here */
 	    if (set_showhr)
-	        fprintf(fp, "<hr noshade><p>\n"); 
+	        fprintf(fp, "<hr>\n"); 
 	}
 	fprintf(fp, "<table>\n");
     }
@@ -2695,7 +2644,7 @@ void write_toplevel_indices(int amountmsgs)
 	}
 	else {
 	    if (set_showhr)
-	        fprintf(fp, "<hr noshade>\n");
+	        fprintf(fp, "<hr>\n");
 	    fprint_summary(fp, PAGE_BOTTOM, firstdatenum, lastdatenum, amountmsgs);
 	    fprint_menu(fp, FOLDERS_INDEX, set_archives, "", "", PAGE_BOTTOM, NULL);
 	}
