@@ -14,7 +14,6 @@
 **              %~ - storage directory
 **              %a - Other Archives URL
 **              %b - About Archive URL
-**              %B - Body line specified
 **              %c - Charset META TAG - Not valid on index pages
 **              %e - email addr of message author - Not valid on index pages
 **              %f - file name of the HTML document
@@ -81,12 +80,10 @@ int printfile(FILE *fp, char *format, char *label, char *subject,
 			putc(*cp, fp);
 		}
 		continue;
-	    case 'B':		/* %B - BODY specified */
-		if (set_htmlbody) {
-		    for (cp = set_htmlbody; *cp; cp++)
-			putc(*cp, fp);
-		}
-		continue;
+	    case 'B':
+	      printf("Warning: the %%B option has been disabled. Use a\n"
+		     "style sheet instead. See the INSTALL file for more info.\n");
+	      continue;
 	    case 'b':		/* %b - About this archive URL */
 		if (set_about) {
 		    for (cp = set_about; *cp; cp++)
@@ -133,8 +130,10 @@ int printfile(FILE *fp, char *format, char *label, char *subject,
 		    putc(*cp, fp);
 		continue;
 	    case 'm':		/* %m - mailto */
-		for (cp = set_mailto; *cp; cp++)
-		    putc(*cp, fp);
+		if (set_mailto) {
+		    for (cp = set_mailto; *cp; cp++)
+			putc(*cp, fp);
+		}
 		continue;
 	    case 'p':		/* %p - PROGNAME */
 		for (cp = PROGNAME; *cp; cp++)
@@ -183,10 +182,10 @@ void print_main_header(FILE *fp, bool index_header, char *label, char *name,
     char *rp;
 
     fprintf(fp,
-	    "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\"\n"
-	    "                      "
-	    "\"http://www.w3.org/TR/REC-html40/loose.dtd\">\n");
-    fprintf(fp, "<html>\n");
+	    "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"\n"
+            "                      "
+	    "\"http://www.w3.org/TR/html4/strict.dtd\">\n");
+    fprintf(fp, "<html lang=\"%s\">\n", set_language);
     fprintf(fp, "<head>\n");
 
     if (charset && *charset) {
@@ -195,23 +194,17 @@ void print_main_header(FILE *fp, bool index_header, char *label, char *name,
 	fprintf(fp, "<meta http-equiv=\"Content-Type\""
 		" content=\"text/html; charset=%s\">\n", charset);
     }
+    fprintf(fp, "<meta name=\"generator\" content=\"%s %s, see %s\">\n",
+                PROGNAME, VERSION, HMURL);
 
     /* 
-     * Assure the title is not longer than 64 characters as is
-     * recommended by the HTML specs. Also, strip off any trailing
-     * whitespace in TITLE so weblint is happy. 
+     * Strip off any trailing whitespace in TITLE so weblint is happy. 
      */
 
     trio_asprintf(&title, "%s: %s", label, rp = convchars(subject));
     free(rp);
 
-    if (!set_iso2022jp && strlen(title) > TITLESTRLEN) {
-	rp = title + (TITLESTRLEN - 1);
-	*rp-- = '\0';
-    }
-    else
-	rp = title + (strlen(title) - 1);
-
+    rp = title + (strlen(title) - 1);
     while (isspace(*rp))
 	*rp-- = '\0';
 
@@ -225,18 +218,29 @@ void print_main_header(FILE *fp, bool index_header, char *label, char *name,
     free(rp);
     if (use_mailto)
 	fprintf(fp, "<link rev=\"made\" href=\"mailto:%s\">\n", set_mailto);
+
     /* print the css url according to the type of header */
-    if (index_header && set_icss_url && *set_icss_url)
-        fprintf(fp, "<link rel=\"Stylesheet\" href=\"%s\">\n", set_icss_url);
-    else if (!index_header && set_mcss_url && *set_mcss_url)
-      fprintf(fp, "<link rel=\"Stylesheet\" href=\"%s\">\n", set_mcss_url);
+    if (index_header && set_icss_url && *set_icss_url) {
+      fprintf(fp, "<link rel=\"stylesheet\" href=\"%s\" type=\"text/css\">\n",
+              set_icss_url);
+
+    } else if (!index_header && set_mcss_url && *set_mcss_url) {
+      fprintf(fp, "<link rel=\"stylesheet\" href=\"%s\" type=\"text/css\">\n",
+              set_mcss_url);
+
+    } else {
+      /*
+       * if style sheets are not specified, emit a default one.
+       */
+      fprintf(fp, "<style type=\"text/css\">\n");
+      fprintf(fp, "body {color: black; background: #ffffff}\n");
+      fprintf(fp, "h1.center {text-align: center}\n");
+      fprintf(fp, "div.center {text-align: center}\n");
+      fprintf(fp, "</style>\n");
+    }
 
     fprintf(fp, "</head>\n");
-
-    if (set_htmlbody)
-	fprintf(fp, "%s\n", set_htmlbody);
-    else
-	fprintf(fp, "<body bgcolor=\"#FFFFFF\" text=\"#000000\">\n");
+    fprintf(fp, "<body>\n");
 }
 
 /*
@@ -255,7 +259,7 @@ void print_msg_header(FILE *fp, char *label, char *subject,
 	print_main_header(fp, FALSE, set_label, name, email, subject,
 			  charset, filename);
 #if 0 /* JK modified this */       
-	fprintf(fp, "<h1 align=\"center\">%s</h1>\n",
+	fprintf(fp, "<h1 class=\"center\">%s</h1>\n",
 		ptr = convchars(subject));
 	free(ptr);
 #endif
@@ -264,7 +268,7 @@ void print_msg_header(FILE *fp, char *label, char *subject,
 	free(ptr);
 #if 0 /* JK: and removed this as it looked a bit strange */
 	if (!set_usetable)
-	    fprintf(fp, "<hr noshade>\n<p>\n");
+	    fprintf(fp, "<hr>\n<p>\n");
 #endif
     }
 }
@@ -281,10 +285,10 @@ void print_index_header(FILE *fp, char *label, char *dir, char *subject,
 		  NULL, NULL, filename);
     else {
 	print_main_header(fp, TRUE, label, NULL, NULL, subject, NULL, NULL);
-	fprintf(fp, "<h1 align=\"center\">%s<br>%s</h1>\n", label, subject);
+	fprintf(fp, "<h1 class=\"center\">%s<br>%s</h1>\n", label, subject);
 #if 0 /*@@ JK: removed it */	
 	if (!set_usetable)
-	    fprintf(fp, "<hr nohade>\n");
+	    fprintf(fp, "<hr>\n");
 #endif
     }
 }
@@ -303,12 +307,12 @@ void printfooter(FILE *fp, char *htmlfooter, char *label, char *dir,
 		  dir, NULL, NULL, NULL, NULL, filename);
     else {
 	if (set_showhr && !set_usetable)
-	    fprintf(fp, "<hr noshade>\n");
-	fprintf(fp, "<p>\n<small>\n<em>\n");
+	    fprintf(fp, "<hr>\n");
+	fprintf(fp, "<p><small><em>\n");
 	fprintf(fp, "%s ", lang[MSG_ARCHIVE_GENERATED_BY]);
 	fprintf(fp, "<a href=\"%s\">%s %s</a> \n", HMURL, PROGNAME, VERSION);
-	fprintf(fp, ": <em>%s</em>\n", getlocaltime());
-	fprintf(fp, "</em>\n</small>\n");
+	fprintf(fp, ": %s\n", getlocaltime());
+	fprintf(fp, "</em></small></p>\n");
 	fprintf(fp, "</body>\n</html>\n");
     }
 }
