@@ -1,5 +1,5 @@
 /*
-** $Id: setup.c,v 1.21 2001/06/26 23:59:23 pcm Exp $
+** $Id: setup.c,v 1.26 2001/11/22 00:39:37 pcm Exp $
 */
 
 #include "hypermail.h"
@@ -53,6 +53,7 @@ bool set_usegdbm;
 #endif
 bool set_append;
 char *set_append_filename;
+bool set_warn_surpressions;
 
 int set_showhtml;
 int set_thrdlevels;
@@ -65,13 +66,16 @@ int set_searchbackmsgnum;
 int set_quote_hide_threshold;
 int set_thread_file_depth;
 
+int set_save_alts;
+char *set_alts_text;
+
 char *set_mailcommand;
 char *set_newmsg_command;
 char *set_replymsg_command;
 char *set_mailto;
 char *set_hmail;
 char *set_domainaddr;
-char *set_htmlbody;
+static char *set_htmlbody;
 
 char *set_icss_url;
 char *set_mcss_url;
@@ -101,6 +105,7 @@ char *set_ihtmlfooter;
 char *set_mhtmlheader;
 char *set_mhtmlfooter;
 char *set_attachmentlink;
+char *set_unsafe_chars;
 
 char *set_folder_by_date;
 char *set_latest_folder;
@@ -179,12 +184,15 @@ struct Config cfg[] = {
      "# msgsperfolder option. Valid types are date, thread, author, \n"
      "# subject, folders, and attachment.\n"},
 
-    {"overwrite", &set_overwrite, BTRUE, CFG_SWITCH,
+    {"overwrite", &set_overwrite, BFALSE, CFG_SWITCH,
      "# Set this to On to make Hypermail overwrite existing archives.\n"},
 
     {"inlinehtml", &set_inlinehtml, BTRUE, CFG_SWITCH,
      "# Define to On to make text/html parts to get inlined with the mails.\n"
-     "# If set to Off, HTML-parts will be stored as separate files.\n"},
+     "# If set to Off, HTML-parts will be stored as separate files.\n"
+     "# A \"Content-Disposition: attachment;\" line in the mail will\n"
+     "# cause an HTML-part to be stored as a separate file even if this\n"
+     "# option is On.\n"},
 
     {"increment", &set_increment, BFALSE, CFG_SWITCH,
      "# Set this to On to append the input to existing archive.\n"},
@@ -347,8 +355,8 @@ struct Config cfg[] = {
      "# Set this to the domainname you want added to a mail address\n"
      "# appearing in the RFC822 field which lack a hostname.\n"},
 
-    {"body", &set_htmlbody, BODY, CFG_STRING,
-     "# This is the <body> line to use when generating the HTML pages.\n"},
+    {"body", &set_htmlbody, NULL, CFG_STRING,
+     "# This obsolete entry kept around to help warn users with old config files.\n"},
 
     {"icss_url", &set_icss_url, NULL, CFG_STRING,
      "# Specifies a URL to an external CSS stylesheet for the index pages.\n"
@@ -370,11 +378,15 @@ struct Config cfg[] = {
 
     {"prefered_types", &set_prefered_types, NULL, CFG_LIST,
      "# When mails using multipart/mixed types are scanned, this list of\n"
-     "# MIME types defines which part you want presented in the result.\n"},
+     "# MIME types defines which part you want presented in the result.\n"
+     "# See the save_alts option for how non prefered types are treated.\n"},
 
     {"ignore_types", &set_ignore_types, NULL, CFG_LIST,
-     "# This is the list of MIME attachment types that  you  do\n"
-     "# not want to do anything with.\n"},
+     "# This is the list of MIME attachment types that you do not want\n"
+     "# to do anything with. Two special types may be used here:\n"
+     "# $BINARY - ignore all types that would be stored as separate files.\n"
+     "# $NONPLAIN - ignore all types not treated as text/plain, and all $BINARY types.\n"
+     "# Note: the behavior of these may be affected by the inlinehtml option.\n"},
 
     {"show_headers", &set_show_headers, NULL, CFG_LIST,
      "# This is the list of headers to be displayed if 'showheaders'\n"
@@ -569,6 +581,36 @@ struct Config cfg[] = {
      "# which match each of these expressions. Uses the same rules for\n"
      "# deletion as the expires option. The expressions use the same\n"
      "# syntax as Perl regular expressions.\n"},
+
+    {"save_alts", &set_save_alts, INT(0), CFG_INTEGER,
+     "# This controls what happens to alternatives (other than the prefered\n"
+     "# alternative) for multipart/alternative messages.\n"
+     "# 0 - discard non-prefered alternatives\n"
+     "# 1 - show all alternatives inline\n"
+     "# 2 - put non-prefered alternatives in a separate file.\n"},
+
+    {"alts_text", &set_alts_text, NULL, CFG_STRING,
+     "# If save_alts is 1, this text is put between the alternatives.\n"
+     "# If save_alts is 2, this text is used to describe the link to each\n"
+     "# alternative file.\n"},
+
+    {"warn_surpressions", &set_warn_surpressions, BTRUE, CFG_SWITCH,
+     "# Set this to On to get warnings (on stdout) about messages that\n"
+     "# are not converted because of they are missing a msgid (if\n"
+     "# require_msgids is On) or because one of the following options\n"
+     "# surpressed it: deleted expires delete_msgnum filter_out\n"
+     "# filter_require filter_out_full_body filter_require_full_body.\n"},
+
+    {"unsafe_chars", &set_unsafe_chars, NULL, CFG_STRING,
+     "# Any characters listed in this string are removed from user-specified\n"
+     "# attachment filenames. Those characters will be replaced by a \"_\"\n"
+     "# (which means that specifying \"_\" here won't have any effect).\n"
+     "# Note that many characters (including / and \\) are removed by the\n"
+     "# safe_filename in parse.c regardless of what this option says. There\n"
+     "# might be some security problems that can be prevented if you specify\n"
+     "# \".\" here (e.g. if a web server is configured to enable server side\n"
+     "# includes on filenames ending in something other than .shtml), but\n"
+     "# that will prevent browsers from recognizing many file types.\n"},
 };
 
 /* ---------------------------------------------------------------- */
@@ -748,6 +790,9 @@ void PostConfig(void)
 	for (i = 0; i <= ATTACHMENT_INDEX; ++i)
 	    show_index[0][i] = show_index[1][i];
     }
+    if (set_htmlbody != NULL)
+	printf("Warning: the body option has been disabled. See the\n"
+	       "INSTALL file for instructions on replacing it with a style sheet.\n");
 }
 
 int ConfigAddItem(char *cfg_line)
@@ -951,7 +996,6 @@ void dump_config(void)
     printf("set_mailto = %s\n",set_mailto ? set_mailto : "Not set");
     printf("set_hmail = %s\n",set_hmail ? set_hmail : "Not set");
     printf("set_domainaddr = %s\n",set_domainaddr ? set_domainaddr : "Not set");
-    printf("set_htmlbody = %s\n",set_htmlbody ? set_htmlbody : "Not set");
     printf("set_icss_url = %s\n",set_icss_url ? set_icss_url : "Not set");
     printf("set_mcss_url = %s\n",set_mcss_url ? set_mcss_url : "Not set");
 
