@@ -78,6 +78,7 @@ extern bool set_usegdbm;
 #endif
 extern bool set_append;
 extern char *set_append_filename;
+extern bool set_warn_surpressions;
 
 extern int set_showhtml;
 extern int set_thrdlevels;
@@ -88,6 +89,9 @@ extern int set_searchbackmsgnum;
 extern int set_quote_hide_threshold;
 extern int set_thread_file_depth;
 
+extern int set_save_alts;
+extern char *set_alts_text;
+
 extern char *set_label;
 
 extern char *set_mailcommand;
@@ -96,7 +100,6 @@ extern char *set_replymsg_command;
 extern char *set_mailto;
 extern char *set_hmail;
 extern char *set_domainaddr;
-extern char *set_htmlbody;
 
 extern char *set_icss_url;
 extern char *set_mcss_url;
@@ -125,6 +128,7 @@ extern char *set_mhtmlheader;
 extern char *set_mhtmlfooter;
 
 extern char *set_attachmentlink;
+extern char *set_unsafe_chars;
 extern bool set_linkquotes;
 
 extern char *set_folder_by_date;
