@@ -197,12 +197,11 @@ void strcpymax(char *dest, const char *src, int n)
     *dest = 0;
 }
 
+#ifndef HAVE_STRCASESTR
 /*
 ** strcasestr() - case insensitive strstr()
 */
 
-#if 1
-
 /* Stolen-- stolen!-- from glibc 2.1. Please don't sue me. */
 
 char *strcasestr (char *phaystack, const char *pneedle)
@@ -290,25 +289,6 @@ foundneedle:
 ret0:
   return 0;
 }
-
-#else
-char *strcasestr(char *haystack, const char *needle)
-{
-    int nlen = strlen(needle);
-    int hlen = strlen(haystack);
-
-    int i;
-    int max;
-
-    max = hlen - nlen;
-
-    for (i = 0; i <= max; i++) {
-	if (!strncasecmp(haystack, needle, nlen))
-	    return haystack;
-	haystack++;
-    }
-    return NULL;
-}
 #endif
 
 /*
