@@ -162,9 +162,9 @@ struct emailinfo *addhash(int num, char *date, char *name,
     if (!msgid) {
 	/* SEVERE ERROR, all mails MUST have a Message-ID, ignore it! */
 	if (set_require_msgids) {
-	    printf
-		("Message-ID is missing, ignoring message with subject '%s'.\n",
-		 subject ? subject : "<unknown>");
+	    if (set_warn_surpressions)
+	        printf("Message-ID is missing, ignoring message with subject '%s'.\n",
+		       subject ? subject : "<unknown>");
 	    return NULL;
 	}
 	else {
@@ -315,12 +315,12 @@ int insert_in_lists(struct emailinfo *emp, const bool *require_filter, int rlen)
 	        if(emp->subdir)
 		    --emp->subdir->count;
 	    }
-	    emp->is_deleted = 1;
+	    emp->is_deleted = FILTERED_DELETE;
 	}
     }
     for(i = 0; i < rlen; ++i) {
 	if (!require_filter[i]) {
-	    emp->is_deleted = 8;
+	    emp->is_deleted = FILTERED_REQUIRED;
 	}
     }
 
@@ -330,6 +330,18 @@ int insert_in_lists(struct emailinfo *emp, const bool *require_filter, int rlen)
 	h->data = emp;
 	h->next = deletedlist;
 	deletedlist = h;
+	if (set_warn_surpressions && require_filter) {
+	    const char *option = "??";
+	    switch(emp->is_deleted)
+	    {
+	    case FILTERED_DELETE:   option = "deleted or delete_msgnum"; break;
+	    case FILTERED_EXPIRE:   option = "expires"; break;
+	    case FILTERED_OUT:      option = "filter_out or filter_out_full_body"; break;
+	    case FILTERED_REQUIRED: option = "filter_require or filter_require_full_body"; break;
+	    }
+	    printf("message %d deleted under option %s. msgid: %s\n",
+		   emp->msgnum+1, option, emp->msgid);
+	}
     }
     else {
         authorlist = addheader(authorlist, emp, 1, 0);
@@ -727,6 +739,36 @@ int rmlastlines(struct body *bp)
     return 0;
 }
 
+/* copy bp on to the end of origbp, deallocate bp */
+
+struct body *
+append_body(struct body *origbp, struct body **origlp, struct body *bp)
+{
+    while (bp) {
+	struct body *next;
+	origbp = addbody(origbp, origlp, bp->line,
+			 (bp->header ? BODY_HEADER : 0)
+			 | (bp->html ? BODY_HTMLIZED : 0)
+			 | (bp->attached ? BODY_ATTACHED : 0));
+	next = bp->next;
+	free(bp->line);
+	free(bp);
+	bp = next;
+    }
+    return origbp;
+}
+
+void free_body(struct body *bp)
+{
+    while (bp != NULL) {
+	struct body *cp = bp->next;
+	if (bp->line)
+	    free(bp->line);
+	free(bp);
+	bp = cp;
+    }
+}
+
 /*
 ** If a message is a reply to another, that message's number and the number of
 ** the message it may be referring to is put in this list.  
@@ -918,32 +960,46 @@ struct header *addheader(struct header *hp,
 }
 
 struct emailsubdir *new_subdir(char *subdir, struct emailsubdir *last_subdir,
-			       char *description)
+			       char *description, time_t date)
 {
     struct emailsubdir *sd = folders;
     struct emailsubdir *new_sd;
+    struct emailsubdir *insert_point = NULL;
     int count;
     char *p;
 
     while (sd) {
 	if (!strcmp(subdir, sd->subdir))
 	    return sd;
+	if (sd->a_date < date
+	    && (!insert_point || sd->a_date > insert_point->a_date))
+	    insert_point = sd;
 	if (sd->next_subdir == NULL)
 	    break;
 	sd = sd->next_subdir;
     }
     new_sd = (struct emailsubdir *)emalloc(sizeof(struct emailsubdir));
-    if (sd == NULL)
-	folders = new_sd;
-    else
-	sd->next_subdir = new_sd;
-    new_sd->prior_subdir = sd;
     new_sd->next_subdir = NULL;
+    new_sd->prior_subdir = NULL;
+    if (insert_point == NULL)
+	insert_point = sd;
+    if (insert_point == NULL)
+	folders = new_sd;
+    else if (date < folders->a_date) {
+	new_sd->next_subdir = folders;
+	folders = new_sd;
+    }
+    else {
+	new_sd->next_subdir = insert_point->next_subdir;
+	insert_point->next_subdir = new_sd;
+	new_sd->prior_subdir = insert_point;
+    }
     new_sd->first_email = NULL;
     new_sd->last_email = NULL;
     new_sd->count = 0;
     new_sd->subdir = strsav(subdir);
     new_sd->description = description;
+    new_sd->a_date = date;
     new_sd->rel_path_to_top = strsav("../");
     count = 0;
     for (p = subdir; *p; ++p)
